local addonName, MaxDps = ...;

LibStub('AceAddon-3.0'):NewAddon(MaxDps, 'MaxDps', 'AceConsole-3.0', 'AceEvent-3.0', 'AceTimer-3.0');

--- @class MaxDps
_G[addonName] = MaxDps;

local TableInsert = tinsert;
local TableRemove = tremove;
local TableContains = tContains;
local TableIndexOf = tIndexOf;

local UnitIsFriend = UnitIsFriend;
local IsPlayerSpell = IsPlayerSpell;
local UnitClass = UnitClass;
local GetSpecialization = GetSpecialization;
local CreateFrame = CreateFrame;
local GetAddOnInfo = GetAddOnInfo;
local IsAddOnLoaded = IsAddOnLoaded;
local LoadAddOn = LoadAddOn;

local spellHistoryBlacklist = {
	[75] = true; -- Auto shot
};

function MaxDps:OnInitialize()
	self.db = LibStub('AceDB-3.0'):New('MaxDpsOptions', self.defaultOptions);

	self:RegisterChatCommand('maxdps', 'ShowMainWindow');

	if not self.db.global.customRotations then
		self.db.global.customRotations = {};
	end

	self:AddToBlizzardOptions();
end

function MaxDps:ShowMainWindow()
	if not self.Window then
		self.Window = self:GetModule('Window');
	end

	self.Window:ShowWindow();
end

function MaxDps:GetTexture()
	if self.db.global.customTexture ~= '' and self.db.global.customTexture ~= nil then
		self.FinalTexture = self.db.global.customTexture;
		return self.FinalTexture;
	end

	self.FinalTexture = self.db.global.texture;
	if self.FinalTexture == '' or self.FinalTexture == nil then
		self.FinalTexture = 'Interface\\Cooldown\\ping4';
	end

	return self.FinalTexture;
end

MaxDps.DefaultPrint = MaxDps.Print;
function MaxDps:Print(...)
	if self.db.global.disabledInfo then
		return
	end

	MaxDps:DefaultPrint(...);
end

MaxDps.profilerStatus = 0;
function MaxDps:ProfilerStart()
	local profiler = self:GetModule('Profiler');
	profiler:StartProfiler();
	self.profilerStatus = 1;
end

function MaxDps:ProfilerStop()
	local profiler = self:GetModule('Profiler');
	profiler:StopProfiler();
	self.profilerStatus = 0;
end

function MaxDps:ProfilerToggle()
	if self.profilerStatus == 0 then
		self:ProfilerStart();
	else
		self:ProfilerStop();
	end
end

function MaxDps:EnableRotation()
	local inCombat = UnitAffectingCombat("player")
	local inVehicle = UnitInVehicle("player")
	if self.NextSpell == nil or self.rotationEnabled then
		self:Print(self.Colors.Error .. 'Failed to enable addon!');
		return
	end

	self:Fetch();
	self:UpdateButtonGlow();

	self:CheckTalents();
	self:GetAzeriteTraits();
	self:GetAzeriteEssences();
	self:GetCovenantInfo();
	self:GetLegendaryEffects();
	self:CheckIsPlayerMelee();
	if self.ModuleOnEnable then
		self.ModuleOnEnable();
	end

    if IsMounted() or inVehicle or not inCombat then
		self:DisableRotation();
		return
    end
	self:EnableRotationTimer();

	self.rotationEnabled = true;
end

function MaxDps:EnableRotationTimer()
	self.RotationTimer = self:ScheduleRepeatingTimer('InvokeNextSpell', self.db.global.interval);
end

function MaxDps:DisableRotation()
	if not self.rotationEnabled then
		return
	end

	self:DisableRotationTimer();

	self:DestroyAllOverlays();
	self:Print(self.Colors.Info .. 'Disabling');

	self.Spell = nil;
	self.rotationEnabled = false;
end

function MaxDps:DisableRotationTimer()
	if self.RotationTimer then
		self:CancelTimer(self.RotationTimer);
	end
end

local talentUpdateEvents = {
	"TRAIT_CONFIG_CREATED",
	"ACTIVE_COMBAT_CONFIG_CHANGED",
	"STARTER_BUILD_ACTIVATION_FAILED",
	"PLAYER_TALENT_UPDATE",
	"AZERITE_ESSENCE_ACTIVATED",
	"TRAIT_CONFIG_DELETED",
	"TRAIT_CONFIG_UPDATED",
	"LOADING_SCREEN_DISABLED",
}

function MaxDps:OnEnable()
	self:RegisterEvent('PLAYER_TARGET_CHANGED');
	self:RegisterEvent('PLAYER_REGEN_DISABLED');

	for _, event in pairs(talentUpdateEvents) do
		self:RegisterEvent(event, 'TalentsUpdated')
	end

	self:RegisterEvent('ACTIONBAR_SLOT_CHANGED', 'ButtonFetch');
	self:RegisterEvent('ACTIONBAR_HIDEGRID', 'ButtonFetch');
	self:RegisterEvent('ACTIONBAR_PAGE_CHANGED', 'ButtonFetch');
	self:RegisterEvent('LEARNED_SPELL_IN_TAB', 'ButtonFetch');
	self:RegisterEvent('CHARACTER_POINTS_CHANGED', 'ButtonFetch');
	self:RegisterEvent('ACTIVE_TALENT_GROUP_CHANGED', 'ButtonFetch');
	self:RegisterEvent('PLAYER_SPECIALIZATION_CHANGED', 'ButtonFetch');
	self:RegisterEvent('UPDATE_MACROS', 'ButtonFetch');
	self:RegisterEvent('VEHICLE_UPDATE', 'ButtonFetch');
	self:RegisterEvent('UPDATE_STEALTH', 'ButtonFetch');

	self:RegisterEvent('UNIT_ENTERED_VEHICLE');
	self:RegisterEvent('UNIT_EXITED_VEHICLE');

	self:RegisterEvent('NAME_PLATE_UNIT_ADDED');
	self:RegisterEvent('NAME_PLATE_UNIT_REMOVED');
	--	self:RegisterEvent('PLAYER_REGEN_ENABLED');

	if not self.playerUnitFrame then
		self.spellHistory = {};

		self.playerUnitFrame = CreateFrame('Frame');
		self.playerUnitFrame:RegisterUnitEvent('UNIT_SPELLCAST_SUCCEEDED', 'player');
		self.playerUnitFrame:SetScript('OnEvent', function(_, _, _, _, spellId)
			-- event, unit, lineId
			if IsPlayerSpell(spellId) and not spellHistoryBlacklist[spellId] then
				TableInsert(self.spellHistory, 1, spellId);

				if #self.spellHistory > 5 then
					TableRemove(self.spellHistory);
				end
			end
		end);
	end

	self:Print(self.Colors.Info .. 'Initialized');
end

MaxDps.visibleNameplates = {};
function MaxDps:NAME_PLATE_UNIT_ADDED(_, nameplateUnit)
	if not TableContains(self.visibleNameplates, nameplateUnit) then
		TableInsert(self.visibleNameplates, nameplateUnit);
	end
end

function MaxDps:NAME_PLATE_UNIT_REMOVED(_, nameplateUnit)
	local index = TableIndexOf(self.visibleNameplates, nameplateUnit);
	if index ~= nil then
		TableRemove(self.visibleNameplates, index)
	end
end

function MaxDps:TalentsUpdated()
	self:DisableRotation();
	self:UpdateSpellsAndTalents()
end

local MaxDpsSpellTable
function MaxDps:UpdateSpellsAndTalents()
    local idtoclass = {
        [1] = "Warrior",
        [2] = "Paladin",
        [3] = "Hunter",
        [4] = "Rogue",
        [5] = "Priest",
        [6] = "Death Knight",
        [7] = "Shaman",
        [8] = "Mage",
        [9] = "Warlock",
        [10] = "Monk",
        [11] = "Druid",
        [12] = "Demon Hunter",
        [13] = "Evoker",
    }
	local idtospec = {
	    --Death Knight
	    [250] = "Blood",
	    [251] = "Frost",
	    [252] = "Unholy",
	    --Demon Hunter
	    [577] = "Havoc",
	    [581] = "Vengeance",
	    --Druid
	    [102] = "Balance",
	    [103] = "Feral",
	    [104] = "Guardian",
	    [105] = "Restoration",
		--Evoker
		[1473] = "Augmentation",
		[1467] = "Devastation",
		[1468] = "Preservation",
	    --Hunter
	    [253] = "Beast Mastery",
	    [254] = "Marksmanship",
	    [255] = "Survival",
	    --Mage
	    [62] = "Arcane",
	    [63] = "Fire",
	    [64] = "Frost",
	    --Monk
	    [268] = "Brewmaster",
	    [269] = "Windwalker",
	    [270] = "Mistweaver",
	    --Paladin
	    [65] = "Holy",
	    [66] = "Protection",
	    [70] = "Retribution",
	    --Priest
	    [256] = "Discipline",
	    [257] = "Holy",
	    [258] = "Shadow",
	    --Rogue
	    [259] = "Assassination",
	    [260] = "Outlaw",
	    [261] = "Subtlety",
	    --Shaman
	    [262] = "Elemental",
	    [263] = "Enhancement",
	    [264] = "Restoration",
	    --Warlock
	    [265] = "Affliction",
	    [266] = "Demonology",
	    [267] = "Destruction",
	    --Warrior
	    [71] = "Arms",
	    [72] = "Fury",
	    [73] = "Protection",
    }
	MaxDpsSpellTable = {
		["Warrior"] = {
			["Arms"] = {
				["SecondWind"] = 29838,
				["BluntInstruments"] = 383442,
				["PiercingVerdict"] = 382948,
				["Skullsplitter"] = 260643,
				["CriticalThinking"] = 389306,
				["Massacre"] = 281001,
				["Overpower"] = 7384,
				["BlademastersTorment"] = 390138,
				["LeechingStrikes"] = 382258,
				["Warbreaker"] = 262161,
				["Charge"] = 100,
				["ArmoredtotheTeeth"] = 384124,
				["ThunderousWords"] = 384969,
				["HeroicThrow"] = 57755,
				["Unhinged"] = 386628,
				["ImprovedOverpower"] = 385571,
				["SuddenDeath"] = 29725,
				["Pummel"] = 6552,
				["ExecutionersPrecision"] = 386634,
				["DeftExperience"] = 389308,
				["MortalStrike"] = 12294,
				["SeismicReverberation"] = 382956,
				["Dreadnaught"] = 262150,
				["SpellReflection"] = 23920,
				["MartialProwess"] = 316440,
				["DiebytheSword"] = 118038,
				["Tactician"] = 184783,
				["Sidearm"] = 384404,
				["CollateralDamage"] = 334779,
				["InForTheKill"] = 248621,
				["Hamstring"] = 1715,
				["Taunt"] = 355,
				["FuriousBlows"] = 390354,
				["SweepingStrikes"] = 260708,
				["Impale"] = 383430,
				["RumblingEarth"] = 275339,
				["TideofBlood"] = 386357,
				["DoubleTime"] = 103827,
				["ThunderousRoar"] = 384318,
				["PainandGain"] = 382549,
				["MercilessBonegrinder"] = 383317,
				["Menace"] = 275338,
				["CrushingForce"] = 382764,
				["BerserkerShout"] = 384100,
				["FervorofBattle"] = 202316,
				["ImprovedExecute"] = 316405,
				["ShieldSlam"] = 23922,
				["Battlelord"] = 386630,
				["IgnorePain"] = 190456,
				["ReapingSwings"] = 383293,
				["ImpendingVictory"] = 202168,
				["Hurricane"] = 390563,
				["ShieldBlock"] = 2565,
				["IntimidatingShout"] = 5246,
				["ThunderClap"] = 396719,
				["FueledbyViolence"] = 383103,
				["Bloodborne"] = 383287,
				["Avatar"] = 107574,
				["Slam"] = 1464,
				["Whirlwind"] = 1680,
				["AngerManagement"] = 152278,
				["ShatteringThrow"] = 64382,
				["SpearofBastion"] = 376079,
				["Two-HandedWeaponSpecialization"] = 382896,
				["WarlordsTorment"] = 390140,
				["ColossusSmash"] = 167105,
				["RallyingCry"] = 97462,
				["EnduranceTraining"] = 382940,
				["BerserkerRage"] = 18499,
				["BattleShout"] = 6673,
				["Fatality"] = 383703,
				["Juggernaut"] = 383292,
				["ImprovedSweepingStrikes"] = 383155,
				["BloodandThunder"] = 384277,
				["Execute"] = 163201,
				["HeroicLeap"] = 6544,
				["CruelStrikes"] = 392777,
				["BattleStance"] = 386164,
				["ConcussiveBlows"] = 383115,
				["WarMachine"] = 262231,
				["BoundingStride"] = 202163,
				["HonedReflexes"] = 382461,
				["StrengthofArms"] = 400803,
				["ImprovedSlam"] = 400205,
				["CacophonousRoar"] = 382954,
				["OverwhelmingRage"] = 382767,
				["SpitefulSerenity"] = 400314,
				["FrothingBerserker"] = 392792,
				["Bladestorm"] = 389774,
				["Cleave"] = 845,
				["BitterImmunity"] = 383762,
				["Rend"] = 772,
				["ExhilaratingBlows"] = 383219,
				["SharpenedBlades"] = 383341,
				["ElysianMight"] = 386285,
				["TestofMight"] = 385008,
				["StormBolt"] = 107570,
				["DefensiveStance"] = 386208,
				["ReinforcedPlates"] = 382939,
				["TitanicThrow"] = 384090,
				["StormofSwords"] = 385512,
				["CracklingThunder"] = 203201,
				["SeasonedSoldier"] = 279423,
				["Mastery:DeepWounds"] = 262111,
				["FastFootwork"] = 382260,
				["StormWall"] = 388807,
				["BarbaricTraining"] = 383082,
				["Bloodsurge"] = 384361,
				["SonicBoom"] = 390725,
				["Shockwave"] = 46968,
				["Intervene"] = 3411,
				["WildStrikes"] = 382946,
				["WreckingThrow"] = 384110,
				["Bloodletting"] = 383154,
				["Uproar"] = 391572,
				["PiercingHowl"] = 12323,
				["DanceofDeath"] = 390713,
				["ValorinVictory"] = 383338,
			},
			["Protection"] = {
				["SecondWind"] = 29838,
				["Charge"] = 100,
				["PiercingVerdict"] = 382948,
				["BatteringRam"] = 394312,
				["Uproar"] = 391572,
				["Massacre"] = 281001,
				["BraceForImpact"] = 386030,
				["LeechingStrikes"] = 382258,
				["PiercingHowl"] = 12323,
				["Riposte"] = 161798,
				["Ravager"] = 228920,
				["ArmoredtotheTeeth"] = 394855,
				["UnnervingFocus"] = 384042,
				["SeismicReverberation"] = 382956,
				["Whirlwind"] = 1680,
				["Revenge"] = 6572,
				["Pummel"] = 6552,
				["HeavyRepercussions"] = 203177,
				["ThunderousWords"] = 384969,
				["SuddenDeath"] = 29725,
				["ImpenetrableWall"] = 384072,
				["Hamstring"] = 1715,
				["Shockwave"] = 46968,
				["ShieldCharge"] = 385952,
				["ThunderousRoar"] = 384318,
				["BestServedCold"] = 202560,
				["Sidearm"] = 384404,
				["UnstoppableForce"] = 275336,
				["HeroicThrow"] = 57755,
				["ShieldSpecialization"] = 386011,
				["Vanguard"] = 71,
				["FuriousBlows"] = 390354,
				["FastFootwork"] = 382260,
				["EnduringAlacrity"] = 384063,
				["ShieldWall"] = 871,
				["LastStand"] = 12975,
				["ThunderClap"] = 6343,
				["SpellReflection"] = 23920,
				["PainandGain"] = 382549,
				["ToughasNails"] = 385888,
				["DoubleTime"] = 103827,
				["Menace"] = 275338,
				["One-HandedWeaponSpecialization"] = 382895,
				["IntotheFray"] = 202603,
				["Bloodsurge"] = 384361,
				["ShieldSlam"] = 23922,
				["Strategist"] = 384041,
				["EnduranceTraining"] = 382940,
				["ChampionsBulwark"] = 386328,
				["ImpendingVictory"] = 202168,
				["ImprovedHeroicThrow"] = 386034,
				["FocusedVigor"] = 384067,
				["IntimidatingShout"] = 5246,
				["Taunt"] = 355,
				["FueledbyViolence"] = 383103,
				["Bloodborne"] = 385704,
				["Avatar"] = 401150,
				["Slam"] = 1464,
				["CrushingForce"] = 390642,
				["AngerManagement"] = 152278,
				["ShatteringThrow"] = 64382,
				["SpearofBastion"] = 376079,
				["Bolster"] = 280001,
				["IgnorePain"] = 190456,
				["Devastator"] = 236279,
				["Juggernaut"] = 393967,
				["BerserkerShout"] = 384100,
				["Mastery:CriticalBlock"] = 76857,
				["BattleShout"] = 6673,
				["Punish"] = 275334,
				["Execute"] = 163201,
				["Battle-ScarredVeteran"] = 386394,
				["BloodandThunder"] = 384277,
				["BattleStance"] = 386164,
				["HeroicLeap"] = 6544,
				["CruelStrikes"] = 392777,
				["ElysianMight"] = 386285,
				["ConcussiveBlows"] = 383115,
				["EnduringDefenses"] = 386027,
				["BerserkerRage"] = 18499,
				["DefensiveStance"] = 386208,
				["RallyingCry"] = 97462,
				["OverwhelmingRage"] = 382767,
				["CacophonousRoar"] = 382954,
				["DisruptingShout"] = 386071,
				["BoundingStride"] = 202163,
				["FrothingBerserker"] = 392790,
				["HonedReflexes"] = 391271,
				["TitanicThrow"] = 384090,
				["BitterImmunity"] = 383762,
				["Rend"] = 394062,
				["BrutalVitality"] = 384036,
				["DemoralizingShout"] = 1160,
				["WarMachine"] = 316733,
				["Indomitable"] = 202095,
				["StormBolt"] = 107570,
				["ImmovableObject"] = 394307,
				["ReinforcedPlates"] = 382939,
				["DeepWounds"] = 115768,
				["ShowofForce"] = 385843,
				["CracklingThunder"] = 203201,
				["Instigate"] = 394311,
				["ShieldBlock"] = 2565,
				["Thunderlord"] = 385840,
				["StormofSteel"] = 382953,
				["BarbaricTraining"] = 390675,
				["WreckingThrow"] = 384110,
				["SonicBoom"] = 390725,
				["RumblingEarth"] = 275339,
				["Intervene"] = 3411,
				["WildStrikes"] = 382946,
				["DefendersAegis"] = 397103,
				["ViolentOutburst"] = 386477,
				["BoomingVoice"] = 202743,
				["ChallengingShout"] = 1161,
				["SpellBlock"] = 392966,
				["DanceofDeath"] = 393965,
			},
			["Fury"] = {
				["SecondWind"] = 29838,
				["Charge"] = 100,
				["PiercingVerdict"] = 382948,
				["TitansTorment"] = 390135,
				["SwiftStrikes"] = 383459,
				["Uproar"] = 391572,
				["CriticalThinking"] = 383297,
				["ImprovedRagingBlow"] = 383854,
				["ArmoredtotheTeeth"] = 384124,
				["ImprovedBloodthirst"] = 383852,
				["Ravager"] = 228920,
				["FreshMeat"] = 215568,
				["LeechingStrikes"] = 382258,
				["PiercingHowl"] = 12323,
				["Bloodcraze"] = 393950,
				["RagingArmaments"] = 388049,
				["Pummel"] = 6552,
				["ThunderousWords"] = 384969,
				["DeftExperience"] = 383295,
				["Cruelty"] = 392931,
				["SeismicReverberation"] = 382956,
				["Warpaint"] = 208154,
				["AshenJuggernaut"] = 392536,
				["ImprovedEnrage"] = 383848,
				["SuddenDeath"] = 280721,
				["RagingBlow"] = 85288,
				["Sidearm"] = 384404,
				["EnragedRegeneration"] = 184364,
				["HeroicThrow"] = 57755,
				["SlaughteringStrikes"] = 388004,
				["Bloodthirst"] = 23881,
				["FuriousBlows"] = 390354,
				["ThunderousRoar"] = 384318,
				["ImpendingVictory"] = 202168,
				["RumblingEarth"] = 275339,
				["Onslaught"] = 315720,
				["DualWieldSpecialization"] = 382900,
				["SpellReflection"] = 23920,
				["PainandGain"] = 382549,
				["UnbridledFerocity"] = 389603,
				["Enrage"] = 184361,
				["DoubleTime"] = 103827,
				["Hamstring"] = 1715,
				["DepthsofInsanity"] = 383922,
				["ImprovedExecute"] = 316402,
				["BarbaricTraining"] = 390674,
				["Slam"] = 1464,
				["Recklessness"] = 1719,
				["Rampage"] = 184367,
				["Single-MindedFury"] = 81099,
				["DefensiveStance"] = 386208,
				["ShieldBlock"] = 2565,
				["IntimidatingShout"] = 5246,
				["Taunt"] = 355,
				["WreckingThrow"] = 384110,
				["Bloodborne"] = 385703,
				["Avatar"] = 107574,
				["Menace"] = 275338,
				["Whirlwind"] = 190411,
				["AngerManagement"] = 152278,
				["ShatteringThrow"] = 64382,
				["SpearofBastion"] = 376079,
				["Tenderize"] = 388933,
				["HonedReflexes"] = 391270,
				["Mastery:UnshackledFury"] = 76856,
				["FrenziedFlurry"] = 383605,
				["EnduranceTraining"] = 391997,
				["CruelStrikes"] = 392777,
				["BattleShout"] = 6673,
				["TitanicRage"] = 394329,
				["BitterImmunity"] = 383762,
				["WarMachine"] = 346002,
				["BloodandThunder"] = 384277,
				["RecklessAbandon"] = 396749,
				["HeroicLeap"] = 6544,
				["DualWield"] = 231842,
				["StormofSwords"] = 388903,
				["TitansGrip"] = 46917,
				["BerserkerRage"] = 18499,
				["ColdSteel,HotBlood"] = 383959,
				["TitanicThrow"] = 384090,
				["RallyingCry"] = 97462,
				["Annihilator"] = 383916,
				["CacophonousRoar"] = 382954,
				["FocusinChaos"] = 383486,
				["BoundingStride"] = 202163,
				["FrothingBerserker"] = 215571,
				["HackandSlash"] = 383877,
				["InvigoratingFury"] = 383468,
				["Hurricane"] = 390563,
				["Frenzy"] = 335077,
				["Execute"] = 5308,
				["OverwhelmingRage"] = 382767,
				["BerserkersTorment"] = 390123,
				["ImprovedWhirlwind"] = 12950,
				["StormBolt"] = 107570,
				["ConcussiveBlows"] = 383115,
				["ReinforcedPlates"] = 382939,
				["ElysianMight"] = 386285,
				["BerserkerShout"] = 384100,
				["CracklingThunder"] = 203201,
				["ViciousContempt"] = 383885,
				["CrushingForce"] = 382764,
				["FastFootwork"] = 382260,
				["StormofSteel"] = 382953,
				["ThunderClap"] = 396719,
				["ShieldSlam"] = 23922,
				["SonicBoom"] = 390725,
				["Shockwave"] = 46968,
				["Intervene"] = 3411,
				["WildStrikes"] = 382946,
				["Massacre"] = 206315,
				["WrathandFury"] = 392936,
				["DancingBlades"] = 391683,
				["MeatCleaver"] = 280392,
				["OdynsFury"] = 385059,
				["BerserkerStance"] = 386196,
			},
		},
		["Paladin"] = {
			["Protection"] = {
				["ImprovedHolyShield"] = 393030,
				["HammerofJustice"] = 853,
				["TurnEvil"] = 10326,
				["Punishment"] = 403530,
				["Riposte"] = 161800,
				["BlessingofProtection"] = 1022,
				["SoaringShield"] = 378457,
				["HammerofWrath"] = 24275,
				["SeasonedWarhorse"] = 376996,
				["FaithsArmor"] = 406101,
				["DivineToll"] = 375576,
				["BlessedHammer"] = 204019,
				["SealofOrder"] = 385129,
				["HammeroftheRighteous"] = 53595,
				["BulwarkofRighteousFury"] = 386653,
				["Redoubt"] = 280373,
				["InmostLight"] = 405757,
				["ImprovedArdentDefender"] = 393114,
				["Cavalier"] = 230332,
				["CleanseToxins"] = 213644,
				["LayonHands"] = 633,
				["SealofMight"] = 385450,
				["UnbreakableSpirit"] = 114154,
				["ResoluteDefender"] = 385422,
				["FlashofLight"] = 19750,
				["GoldenPath"] = 377128,
				["SealofAlacrity"] = 385425,
				["AurasofSwiftVengeance"] = 385639,
				["Consecration"] = 26573,
				["AegisofLight"] = 353367,
				["ShieldoftheRighteous"] = 53600,
				["InnerLight"] = 386568,
				["HolyAegis"] = 385515,
				["Justification"] = 377043,
				["Rebuke"] = 96231,
				["HandofReckoning"] = 62124,
				["BlessingofSpellwarding"] = 204018,
				["DivinePurpose"] = 223817,
				["FerrenMarcussFervor"] = 378762,
				["CrusadersJudgment"] = 204023,
				["DivineResonance"] = 386738,
				["Mastery:DivineBulwark"] = 76671,
				["AvengersShield"] = 31935,
				["BlessingofFreedom"] = 1044,
				["SealofReprisal"] = 377053,
				["ZealotsParagon"] = 391142,
				["GrandCrusader"] = 85043,
				["RelentlessInquisitor"] = 383388,
				["Obduracy"] = 385427,
				["QuickenedInvocation"] = 379391,
				["Judgment"] = 275779,
				["GreaterJudgment"] = 231663,
				["JudgmentofLight"] = 183778,
				["FistofJustice"] = 234299,
				["AurasoftheResolute"] = 385633,
				["UthersCounsel"] = 378425,
				["DivineShield"] = 642,
				["Intercession"] = 391054,
				["SacrificeoftheJust"] = 384820,
				["HandoftheProtector"] = 315924,
				["ConsecratedGround"] = 204054,
				["StrengthinAdversity"] = 393071,
				["BastionofLight"] = 378974,
				["FaithintheLight"] = 379043,
				["DivineSteed"] = 190784,
				["FocusedEnmity"] = 378845,
				["Sentinel"] = 389539,
				["AvengingWrath"] = 31884,
				["FinalStand"] = 204077,
				["MomentofGlory"] = 327193,
				["Sanctuary"] = 379021,
				["TouchofLight"] = 385349,
				["Recompense"] = 384914,
				["SenseUndead"] = 5502,
				["GuardianofAncientKings"] = 86659,
				["BulwarkofOrder"] = 209389,
				["BarricadeofFaith"] = 385726,
				["ArdentDefender"] = 31850,
				["EyeofTyr"] = 387174,
				["SanctifiedPlates"] = 402964,
				["SealofMercy"] = 384897,
				["SealoftheCrusader"] = 385728,
				["ConcentrationAura"] = 317920,
				["StrengthofConviction"] = 379008,
				["CrusadersReprieve"] = 403042,
				["FadingLight"] = 405768,
				["GiftoftheGoldenValkyr"] = 378279,
				["ConsecrationinFlame"] = 379022,
				["BlindingLight"] = 115750,
				["LightoftheTitans"] = 378405,
				["SealofCharity"] = 384815,
				["OfDuskandDawn"] = 409441,
				["ImprovedBlessingofProtection"] = 384909,
				["TyrsEnforcer"] = 378285,
				["ShiningLight"] = 321136,
				["BlessingofSacrifice"] = 6940,
				["DevotionAura"] = 465,
				["WordofGlory"] = 85673,
				["HolyShield"] = 152261,
				["Incandescence"] = 385464,
				["Afterimage"] = 385414,
				["UnboundFreedom"] = 305394,
				["RighteousProtector"] = 204074,
				["LightforgedBlessing"] = 406468,
				["TirionsDevotion"] = 392928,
				["CrusadersResolve"] = 380188,
				["Contemplation"] = 121183,
				["InspiringVanguard"] = 393022,
				["Redemption"] = 7328,
				["Repentance"] = 20066,
			},
			["Holy"] = {
				["Daybreak"] = 414170,
				["HammerofJustice"] = 853,
				["TurnEvil"] = 10326,
				["GloriousDawn"] = 414065,
				["Punishment"] = 403530,
				["BlessingofProtection"] = 1022,
				["BlessingofSummer"] = 388007,
				["Cleanse"] = 4987,
				["Veneration"] = 392938,
				["HammerofWrath"] = 24275,
				["HolyInfusion"] = 414214,
				["FaithsArmor"] = 406101,
				["DivineToll"] = 375576,
				["ConcentrationAura"] = 317920,
				["MomentofCompassion"] = 387786,
				["Justification"] = 377043,
				["RisingSunlight"] = 414203,
				["BlessingofFreedom"] = 1044,
				["LightofDawn"] = 85222,
				["TyrsDeliverance"] = 200652,
				["TowerofRadiance"] = 231642,
				["Absolution"] = 212056,
				["Incandescence"] = 385464,
				["LightforgedBlessing"] = 406468,
				["SeasonedWarhorse"] = 376996,
				["OverflowingLight"] = 414127,
				["DivineFavor"] = 210294,
				["LightsConviction"] = 414073,
				["LayonHands"] = 633,
				["Contemplation"] = 121183,
				["CrusaderStrike"] = 35395,
				["Illumination"] = 414378,
				["UnbreakableSpirit"] = 114154,
				["HandofDivinity"] = 414273,
				["Consecration"] = 26573,
				["InfusionofLight"] = 53576,
				["AuraMastery"] = 31821,
				["FlashofLight"] = 19750,
				["GoldenPath"] = 377128,
				["GlisteningRadiance"] = 414139,
				["UnendingLight"] = 387998,
				["AurasofSwiftVengeance"] = 385639,
				["Reclamation"] = 415364,
				["Awakening"] = 414195,
				["InflorescenceoftheSunwell"] = 392907,
				["Mastery:Lightbringer"] = 183997,
				["BreakingDawn"] = 387879,
				["DivinePurpose"] = 223817,
				["HolyAegis"] = 385515,
				["DivineResonance"] = 386738,
				["BeaconoftheLightbringer"] = 197446,
				["LightsProtection"] = 416799,
				["ShiningRighteousness"] = 414443,
				["HandofReckoning"] = 62124,
				["DivineShield"] = 642,
				["BarrierofFaith"] = 148039,
				["BlessedFocus"] = 414708,
				["RelentlessInquisitor"] = 383388,
				["LightoftheMartyr"] = 183998,
				["Awestruck"] = 417855,
				["SanctifiedWrath"] = 53376,
				["QuickenedInvocation"] = 379391,
				["Intercession"] = 391054,
				["HolyShock"] = 20473,
				["FadingLight"] = 405768,
				["DivineProtection"] = 498,
				["Judgment"] = 275773,
				["GreaterJudgment"] = 231644,
				["CrusadersReprieve"] = 403042,
				["FistofJustice"] = 234299,
				["HolyPrism"] = 114165,
				["SealoftheCrusader"] = 416770,
				["DevotionAura"] = 465,
				["GlimmerofLight"] = 287269,
				["Obduracy"] = 385427,
				["SealofMight"] = 385450,
				["Repentance"] = 20066,
				["CrusadersMight"] = 196926,
				["SealofOrder"] = 385129,
				["SacrificeoftheJust"] = 384820,
				["DivineSteed"] = 190784,
				["BeaconofFaith"] = 156910,
				["SealofAlacrity"] = 385425,
				["AvengingWrath"] = 31884,
				["SealofMercy"] = 384897,
				["SenseUndead"] = 5502,
				["ImprovedBlessingofProtection"] = 384909,
				["TouchofLight"] = 385349,
				["BeaconofLight"] = 53563,
				["DivineRevelations"] = 387808,
				["HolyLight"] = 82326,
				["ResplendentLight"] = 392902,
				["Recompense"] = 384914,
				["Afterimage"] = 385414,
				["UnwaveringSpirit"] = 392911,
				["Cavalier"] = 230332,
				["LightsHammer"] = 114158,
				["Rebuke"] = 96231,
				["AurasoftheResolute"] = 385633,
				["StrengthofConviction"] = 379008,
				["EmpyreanLegacy"] = 387170,
				["VanguardsMomentum"] = 416869,
				["ImprovedCleanse"] = 393024,
				["JudgmentofLight"] = 183778,
				["BlindingLight"] = 115750,
				["ProtectionofTyr"] = 200430,
				["SanctifiedPlates"] = 402964,
				["OfDuskandDawn"] = 409439,
				["SavedbytheLight"] = 157047,
				["AvengingCrusader"] = 216331,
				["ImbuedInfusions"] = 392961,
				["BlessingofSacrifice"] = 6940,
				["PoweroftheSilverHand"] = 200474,
				["WordofGlory"] = 85673,
				["EchoingBlessings"] = 387801,
				["RighteousJudgment"] = 414113,
				["CommandingLight"] = 387781,
				["UntemperedDedication"] = 387814,
				["ShieldoftheRighteous"] = 415091,
				["BoundlessSalvation"] = 392951,
				["TirionsDevotion"] = 414720,
				["MaraadsDyingBreath"] = 388018,
				["BeaconofVirtue"] = 200025,
				["MercifulAuras"] = 183415,
				["Redemption"] = 7328,
				["DivineGlimpse"] = 387805,
			},
			["Retribution"] = {
				["BlessedChampion"] = 403010,
				["HeartoftheCrusader"] = 406154,
				["FinalVerdict"] = 383328,
				["Punishment"] = 403530,
				["Penitence"] = 403026,
				["BlessingofProtection"] = 1022,
				["TempestoftheLightbringer"] = 383396,
				["Incandescence"] = 385464,
				["HammerofWrath"] = 24275,
				["SeasonedWarhorse"] = 376996,
				["FaithsArmor"] = 406101,
				["DivineToll"] = 375576,
				["Justification"] = 377043,
				["JusticarsVengeance"] = 215661,
				["BlessingofFreedom"] = 1044,
				["ZealotsFervor"] = 403509,
				["SealofOrder"] = 385129,
				["Expurgation"] = 383344,
				["ShieldoftheRighteous"] = 53600,
				["SwiftJustice"] = 383228,
				["Cavalier"] = 230332,
				["CleanseToxins"] = 213644,
				["ExecutionSentence"] = 343527,
				["LayonHands"] = 633,
				["Redemption"] = 7328,
				["HammerofJustice"] = 853,
				["SealofMight"] = 385450,
				["UnbreakableSpirit"] = 114154,
				["TruthsWake"] = 403696,
				["FlashofLight"] = 19750,
				["GoldenPath"] = 377128,
				["LightofJustice"] = 404436,
				["CrusaderAura"] = 32223,
				["Contemplation"] = 121183,
				["SealofAlacrity"] = 385425,
				["DivineArbiter"] = 404306,
				["AurasofSwiftVengeance"] = 385639,
				["ArtofWar"] = 406064,
				["TurnEvil"] = 10326,
				["TemplarStrikes"] = 406646,
				["Mastery:HandofLight"] = 267316,
				["ImprovedCrusaderStrike"] = 383254,
				["HolyAegis"] = 385515,
				["Crusade"] = 231895,
				["ImprovedJudgment"] = 405461,
				["Rebuke"] = 96231,
				["TemplarStrike"] = 407480,
				["Jurisdiction"] = 402971,
				["HandofReckoning"] = 62124,
				["BladesofLight"] = 403664,
				["JudgmentofLight"] = 183778,
				["DivineResonance"] = 384027,
				["ConsecratedBlade"] = 404834,
				["DivineStorm"] = 53385,
				["RighteousCause"] = 402912,
				["QuickenedInvocation"] = 379391,
				["InstrumentofRetribution"] = 404752,
				["BladeofJustice"] = 184575,
				["DivineShield"] = 642,
				["GuidedPrayer"] = 404357,
				["DivineProtection"] = 403876,
				["Judgment"] = 20271,
				["GreaterJudgment"] = 231663,
				["CrusadingStrikes"] = 404542,
				["Obduracy"] = 385427,
				["AurasoftheResolute"] = 385633,
				["Adjudication"] = 406157,
				["LightsCelerity"] = 403698,
				["Intercession"] = 391054,
				["HealingHands"] = 326734,
				["Sanctify"] = 382536,
				["SearingLight"] = 404540,
				["SanctifiedPlates"] = 402964,
				["SealoftheCrusader"] = 385728,
				["SacrificeoftheJust"] = 384820,
				["DivineSteed"] = 190784,
				["ImprovedBladeofJustice"] = 403745,
				["RushofLight"] = 407067,
				["AvengingWrath"] = 31884,
				["SealofMercy"] = 384897,
				["VanguardsMomentum"] = 383314,
				["ImprovedBlessingofProtection"] = 384909,
				["TouchofLight"] = 385349,
				["StrengthofConviction"] = 379008,
				["SenseUndead"] = 5502,
				["EmpyreanPower"] = 326732,
				["BladeofVengeance"] = 403826,
				["Recompense"] = 384914,
				["FinalReckoning"] = 343721,
				["VanguardofJustice"] = 406545,
				["CrusadersReprieve"] = 403042,
				["HolyBlade"] = 383342,
				["RetributionAura"] = 183435,
				["AegisofProtection"] = 403654,
				["Judge,JuryandExecutioner"] = 405607,
				["EmpyreanLegacy"] = 387170,
				["FadingLight"] = 405768,
				["ShieldofVengeance"] = 184662,
				["DivineHammer"] = 198034,
				["BlindingLight"] = 115750,
				["ExecutionersWill"] = 406940,
				["InquisitorsIre"] = 403975,
				["OfDuskandDawn"] = 385125,
				["SeethingFlames"] = 405355,
				["WakeofAshes"] = 255937,
				["FistofJustice"] = 234299,
				["BlessingofSacrifice"] = 6940,
				["ConsecratedGround"] = 204054,
				["WordofGlory"] = 85673,
				["DivinePurpose"] = 408459,
				["DivineWrath"] = 406872,
				["Afterimage"] = 385414,
				["LightforgedBlessing"] = 403479,
				["BoundlessJudgment"] = 405278,
				["HighlordsJudgment"] = 404512,
				["JudgmentofJustice"] = 403495,
				["BurningCrusade"] = 405289,
				["UnboundFreedom"] = 305394,
				["DivineAuxiliary"] = 406158,
				["VengefulWrath"] = 406835,
				["Repentance"] = 20066,
			},
		},
		["Shaman"] = {
			["Enhancement"] = {
				["ForcefulWinds"] = 262647,
				["Stormflurry"] = 344357,
				["NaturesGuardian"] = 30884,
				["FlameShock"] = 188389,
				["PlanesTraveler"] = 381647,
				["Stormblast"] = 319930,
				["StaticAccumulation"] = 384411,
				["Flurry"] = 382888,
				["WindfuryWeapon"] = 33757,
				["WitchDoctorsAncestry"] = 384447,
				["FeralSpirit"] = 51533,
				["EarthbindTotem"] = 2484,
				["CrashingStorms"] = 334308,
				["GowiththeFlow"] = 381678,
				["FrostShock"] = 196840,
				["ElementalWeapons"] = 384355,
				["FireNova"] = 333974,
				["StormsWrath"] = 392352,
				["Reincarnation"] = 20608,
				["FeralLunge"] = 196884,
				["VoodooMastery"] = 204268,
				["AlphaWolf"] = 198434,
				["Ascendance"] = 114051,
				["ThorimsInvocation"] = 384444,
				["PrimordialWave"] = 375982,
				["FlametongueWeapon"] = 318038,
				["RagingMaelstrom"] = 384143,
				["CalloftheElements"] = 383011,
				["StoneskinTotem"] = 383017,
				["SpiritWalk"] = 58875,
				["CrashLightning"] = 187874,
				["PrimalMaelstrom"] = 384405,
				["StaticCharge"] = 265046,
				["ConvergingStorms"] = 384363,
				["IceStrike"] = 342240,
				["ChainLightning"] = 188443,
				["NaturesFury"] = 381655,
				["Hex"] = 51514,
				["TempestStrikes"] = 428071,
				["TranquilAirTotem"] = 383019,
				["ImprovedMaelstromWeapon"] = 383303,
				["DoomWinds"] = 384352,
				["LavaLash"] = 60103,
				["AncestralWolfAffinity"] = 382197,
				["SurgingShields"] = 382033,
				["SpiritWolf"] = 260878,
				["EarthgrabTotem"] = 51485,
				["LegacyoftheFrostWitch"] = 384450,
				["Enfeeblement"] = 378079,
				["ManaSpring"] = 381930,
				["MoltenAssault"] = 334033,
				["FarSight"] = 6196,
				["AstralShift"] = 108271,
				["WindsofAlAkir"] = 382215,
				["Thundershock"] = 378779,
				["ThunderousPaws"] = 378075,
				["PoisonCleansingTotem"] = 383013,
				["SwirlingMaelstrom"] = 384359,
				["Purge"] = 370,
				["HotHand"] = 201900,
				["ElementalBlast"] = 117014,
				["WindShear"] = 57994,
				["CreationCore"] = 383012,
				["CapacitorTotem"] = 192058,
				["Thunderstorm"] = 51490,
				["Stormstrike"] = 17364,
				["TotemicSurge"] = 381867,
				["WindfuryTotem"] = 8512,
				["SplinteredElements"] = 382042,
				["GreaterPurge"] = 378773,
				["LightningShield"] = 192106,
				["AstralBulwark"] = 377933,
				["ElementalSpirits"] = 262624,
				["UnrulyWinds"] = 390288,
				["CleanseSpirit"] = 51886,
				["SpiritwalkersGrace"] = 79206,
				["Mastery:EnhancedElements"] = 77223,
				["FocusedInsight"] = 381666,
				["OverflowingMaelstrom"] = 384149,
				["RefreshingWaters"] = 393905,
				["ElementalAssault"] = 210853,
				["Sundering"] = 197214,
				["GracefulSpirit"] = 192088,
				["AshenCatalyst"] = 390370,
				["GhostWolf"] = 2645,
				["GustofWind"] = 192063,
				["BrimmingwithLife"] = 381689,
				["WindRushTotem"] = 192077,
				["ElementalWarding"] = 381650,
				["TremorTotem"] = 8143,
				["Hailstorm"] = 334195,
				["WaterWalking"] = 546,
				["SwirlingCurrents"] = 378094,
				["NaturesSwiftness"] = 378081,
				["LashingFlames"] = 334046,
				["ChainHeal"] = 1064,
				["SpiritwalkersAegis"] = 378077,
				["FireandIce"] = 382886,
				["AncestralSpirit"] = 2008,
				["TotemicFocus"] = 382201,
				["EarthElemental"] = 198103,
				["LightningLasso"] = 305483,
				["AncestralDefense"] = 382947,
				["HealingStreamTotem"] = 5394,
				["MaelstromWeapon"] = 187880,
				["AncestralGuidance"] = 108281,
				["TotemicRecall"] = 108285,
				["LightningBolt"] = 188196,
				["Bloodlust"] = 2825,
				["LavaBurst"] = 51505,
				["EarthShield"] = 974,
				["TotemicProjection"] = 108287,
				["GuardiansCudgel"] = 381819,
				["DeeplyRootedElements"] = 378270,
				["AstralRecall"] = 556,
				["HealingSurge"] = 8004,
				["ElementalOrbit"] = 383010,
			},
			["Restoration"] = {
				["ManaTideTotem"] = 16191,
				["TidalWaves"] = 51564,
				["CurrentControl"] = 404015,
				["EarthShield"] = 974,
				["Downpour"] = 207778,
				["EarthenHarmony"] = 382020,
				["FlameShock"] = 188389,
				["CreationCore"] = 383012,
				["NaturesGuardian"] = 30884,
				["Wellspring"] = 197995,
				["Flurry"] = 382888,
				["MasteroftheElements"] = 16166,
				["LivingStream"] = 382482,
				["Ascendance"] = 114052,
				["LavaSurge"] = 77756,
				["EarthbindTotem"] = 2484,
				["Resurgence"] = 16196,
				["AcidRain"] = 378443,
				["GowiththeFlow"] = 381678,
				["PlanesTraveler"] = 381647,
				["LightningLasso"] = 305483,
				["Undercurrent"] = 382194,
				["FrostShock"] = 196840,
				["PrimalStrike"] = 73899,
				["CloudburstTotem"] = 157153,
				["AncestralProtectionTotem"] = 207399,
				["AncestralVision"] = 212048,
				["HealingStreamTotem"] = 5394,
				["HealingWave"] = 77472,
				["VoodooMastery"] = 204268,
				["WindShear"] = 57994,
				["TumblingWaves"] = 382040,
				["DeeplyRootedElements"] = 378270,
				["SurgingShields"] = 382033,
				["FlametongueWeapon"] = 318038,
				["AncestralWolfAffinity"] = 382197,
				["CalloftheElements"] = 383011,
				["TotemicSurge"] = 381867,
				["SpiritWalk"] = 58875,
				["Deluge"] = 200076,
				["UnleashLife"] = 73685,
				["StaticCharge"] = 265046,
				["ImprovedPrimordialWave"] = 382191,
				["TotemicProjection"] = 108287,
				["ThunderousPaws"] = 378075,
				["HighTide"] = 157154,
				["Hex"] = 51514,
				["TotemicFocus"] = 382201,
				["TranquilAirTotem"] = 383019,
				["Riptide"] = 61295,
				["EchooftheElements"] = 333919,
				["LavaBurst"] = 51505,
				["FlashFlood"] = 280614,
				["Enfeeblement"] = 378079,
				["SpiritWolf"] = 260878,
				["EarthgrabTotem"] = 51485,
				["AncestralGuidance"] = 108281,
				["EarthenWallTotem"] = 198838,
				["PrimordialWave"] = 428332,
				["WaterShield"] = 52127,
				["FarSight"] = 6196,
				["AstralShift"] = 108271,
				["WindsofAlAkir"] = 382215,
				["Thundershock"] = 378779,
				["ContinuousWaves"] = 382046,
				["SpiritLinkTotem"] = 98008,
				["MaelstromWeapon"] = 187880,
				["AncestralVigor"] = 207401,
				["EarthlivingWeapon"] = 382021,
				["SpiritwalkersTidalTotem"] = 404522,
				["WindRushTotem"] = 192077,
				["ImprovedPurifySpirit"] = 383016,
				["CapacitorTotem"] = 192058,
				["Undulation"] = 200071,
				["EarthElemental"] = 198103,
				["AstralBulwark"] = 377933,
				["TideTurner"] = 404019,
				["FlowoftheTides"] = 382039,
				["GreaterPurge"] = 378773,
				["LightningShield"] = 192106,
				["GhostWolf"] = 2645,
				["SpiritwalkersGrace"] = 79206,
				["AncestralAwakening"] = 382309,
				["SpiritwalkersAegis"] = 378077,
				["ImprovedEarthlivingWeapon"] = 382315,
				["TremorTotem"] = 8143,
				["Torrent"] = 200072,
				["ResonantWaters"] = 404539,
				["RefreshingWaters"] = 378211,
				["Mastery:DeepHealing"] = 77226,
				["AncestralReach"] = 382732,
				["GracefulSpirit"] = 192088,
				["NaturesFury"] = 381655,
				["PrimalTideCore"] = 382045,
				["WavespeakersBlessing"] = 381946,
				["BrimmingwithLife"] = 381689,
				["HealingTideTotem"] = 108280,
				["GustofWind"] = 192063,
				["WaterTotemMastery"] = 382030,
				["Stormkeeper"] = 383009,
				["WaterWalking"] = 546,
				["SwirlingCurrents"] = 378094,
				["NaturesSwiftness"] = 378081,
				["Thunderstorm"] = 51490,
				["ChainHeal"] = 1064,
				["ElementalWarding"] = 381650,
				["FireandIce"] = 382886,
				["AncestralSpirit"] = 2008,
				["OverflowingShores"] = 383222,
				["HealingRain"] = 73920,
				["StoneskinTotem"] = 383017,
				["AncestralDefense"] = 382947,
				["ChainLightning"] = 188443,
				["PoisonCleansingTotem"] = 383013,
				["Purge"] = 370,
				["TotemicRecall"] = 108285,
				["LightningBolt"] = 188196,
				["Bloodlust"] = 2825,
				["Tidebringer"] = 236501,
				["ManaSpring"] = 381930,
				["Reincarnation"] = 20608,
				["GuardiansCudgel"] = 381819,
				["PurifySpirit"] = 77130,
				["AstralRecall"] = 556,
				["HealingSurge"] = 8004,
				["ElementalOrbit"] = 383010,
			},
			["Elemental"] = {
				["UnrelentingCalamity"] = 382685,
				["MountainsWillFall"] = 381726,
				["NaturesGuardian"] = 30884,
				["FlamesoftheCauldron"] = 378266,
				["PlanesTraveler"] = 381647,
				["Reincarnation"] = 20608,
				["LavaSurge"] = 77756,
				["Flurry"] = 382888,
				["MasteroftheElements"] = 16166,
				["FlameShock"] = 188389,
				["Ascendance"] = 114050,
				["SwellingMaelstrom"] = 381707,
				["SurgeofPower"] = 262303,
				["LightningLasso"] = 305483,
				["LiquidMagmaTotem"] = 192222,
				["GowiththeFlow"] = 381678,
				["FlowofPower"] = 385923,
				["Icefury"] = 210714,
				["PrimalElementalist"] = 117013,
				["FrostShock"] = 196840,
				["EarthShield"] = 974,
				["Aftershock"] = 273221,
				["ManaSpring"] = 381930,
				["FluxMelting"] = 381776,
				["Inundate"] = 378776,
				["PoweroftheMaelstrom"] = 191861,
				["VoodooMastery"] = 204268,
				["WindShear"] = 57994,
				["FireElemental"] = 198067,
				["StoneskinTotem"] = 383017,
				["ElectrifiedShocks"] = 382086,
				["FlametongueWeapon"] = 318038,
				["ChainLightning"] = 188443,
				["CalloftheElements"] = 383011,
				["TotemicSurge"] = 381867,
				["SpiritWalk"] = 58875,
				["CallofFire"] = 378255,
				["Earthquake"] = 61882,
				["StaticCharge"] = 265046,
				["OathoftheFarSeer"] = 381785,
				["TotemicProjection"] = 108287,
				["ThunderousPaws"] = 378075,
				["NaturesFury"] = 381655,
				["DeeplyRootedElements"] = 378270,
				["TotemicFocus"] = 382201,
				["TranquilAirTotem"] = 383019,
				["SurgingShields"] = 382033,
				["EchoesofGreatSundering"] = 384087,
				["LavaBurst"] = 51505,
				["AncestralWolfAffinity"] = 382197,
				["CreationCore"] = 383012,
				["SpiritWolf"] = 260878,
				["EchooftheElements"] = 333919,
				["AncestralGuidance"] = 108281,
				["PrimordialFury"] = 378193,
				["PrimordialBond"] = 381764,
				["GustofWind"] = 192063,
				["ElementalEquilibrium"] = 378271,
				["AstralShift"] = 108271,
				["MagmaChamber"] = 381932,
				["Thundershock"] = 378779,
				["FireandIce"] = 382886,
				["Purge"] = 370,
				["MaelstromWeapon"] = 187880,
				["WindsofAlAkir"] = 382215,
				["CleanseSpirit"] = 51886,
				["ElementalBlast"] = 117014,
				["WaterWalking"] = 546,
				["FurtherBeyond"] = 381787,
				["CapacitorTotem"] = 192058,
				["Thunderstorm"] = 51490,
				["EarthElemental"] = 198103,
				["SpiritwalkersAegis"] = 378077,
				["EyeoftheStorm"] = 381708,
				["EarthShock"] = 8042,
				["SplinteredElements"] = 382042,
				["LightningShield"] = 192106,
				["TumultuousFissures"] = 381743,
				["LightningRod"] = 210689,
				["EchoChamber"] = 382032,
				["AstralBulwark"] = 377933,
				["WindspeakersLavaResurgence"] = 378268,
				["RefreshingWaters"] = 378211,
				["FocusedInsight"] = 381666,
				["Stormkeeper"] = 191634,
				["Mastery:ElementalOverload"] = 168534,
				["GreaterPurge"] = 378773,
				["RollingMagma"] = 386443,
				["GracefulSpirit"] = 192088,
				["Enfeeblement"] = 378079,
				["Hex"] = 51514,
				["EarthgrabTotem"] = 51485,
				["WindRushTotem"] = 192077,
				["ElementalWarding"] = 381650,
				["BrimmingwithLife"] = 381689,
				["TremorTotem"] = 8143,
				["SpiritwalkersGrace"] = 79206,
				["GhostWolf"] = 2645,
				["SwirlingCurrents"] = 378094,
				["NaturesSwiftness"] = 378081,
				["CallofThunder"] = 378241,
				["ChainHeal"] = 1064,
				["SkybreakersFieryDemise"] = 378310,
				["ElementalFury"] = 60188,
				["AncestralSpirit"] = 2008,
				["FarSight"] = 6196,
				["StormElemental"] = 192249,
				["HealingStreamTotem"] = 5394,
				["AncestralDefense"] = 382947,
				["PrimordialSurge"] = 386474,
				["SearingFlames"] = 381782,
				["FlashofLightning"] = 381936,
				["TotemicRecall"] = 108285,
				["LightningBolt"] = 188196,
				["Bloodlust"] = 2825,
				["PrimalStrike"] = 73899,
				["PoisonCleansingTotem"] = 383013,
				["HealingSurge"] = 8004,
				["GuardiansCudgel"] = 381819,
				["ImprovedFlametongueWeapon"] = 382027,
				["AstralRecall"] = 556,
				["PrimordialWave"] = 375982,
				["ElementalOrbit"] = 383010,
			},
		},
		["Monk"] = {
			["Mistweaver"] = {
				["CalmingPresence"] = 388664,
				["Revival"] = 115310,
				["GenerousPour"] = 389575,
				["ZenPulse"] = 124081,
				["Upwelling"] = 274963,
				["MysticTouch"] = 8647,
				["FortifyingBrew"] = 115203,
				["ImprovedParalysis"] = 344359,
				["RefreshingJadeWind"] = 196725,
				["ElusiveMists"] = 388681,
				["LegacyofWisdom"] = 404408,
				["Transcendence"] = 101643,
				["FontofLife"] = 337209,
				["IronshellBrew"] = 388814,
				["EssenceFont"] = 191837,
				["MistyPeaks"] = 388682,
				["VeilofPride"] = 400053,
				["InvokersDelight"] = 388661,
				["NourishingChi"] = 387765,
				["ResonantFists"] = 389578,
				["Paralysis"] = 115078,
				["StrengthofSpirit"] = 387276,
				["GiftoftheCelestials"] = 388212,
				["ProfoundRebuttal"] = 392910,
				["CracklingJadeLightning"] = 117952,
				["CalmingCoalescence"] = 388218,
				["EnvelopingMist"] = 124682,
				["RenewingMist"] = 115151,
				["TeachingsoftheMonastery"] = 116645,
				["SummonBlackOxStatue"] = 115315,
				["FaelineStomp"] = 388193,
				["TigerTailSweep"] = 264348,
				["SoothingMist"] = 115175,
				["Restoral"] = 388615,
				["SaveThemAll"] = 389579,
				["BurstofLife"] = 399226,
				["Roll"] = 109132,
				["GraceoftheCrane"] = 388811,
				["TearofMorning"] = 387991,
				["UpliftedSpirits"] = 388551,
				["CloudedFocus"] = 388047,
				["YulonsWhisper"] = 388038,
				["ImprovedRoll"] = 328669,
				["InvigoratingMists"] = 274586,
				["DancingMists"] = 388701,
				["ChiWave"] = 115098,
				["VigorousExpulsion"] = 392900,
				["AwakenedFaeline"] = 388779,
				["Reawaken"] = 212051,
				["TouchofDeath"] = 322109,
				["TigersLust"] = 116841,
				["InvokeYulon,theJadeSerpent"] = 322118,
				["ExpeditiousFortification"] = 388813,
				["ShaohaosLessons"] = 400089,
				["ExpelHarm"] = 322101,
				["ThunderFocusTea"] = 116680,
				["SongofChi-Ji"] = 198898,
				["PeacefulMending"] = 388593,
				["TeaofPlenty"] = 388517,
				["ChiTorpedo"] = 115008,
				["Resuscitate"] = 115178,
				["MendingProliferation"] = 388509,
				["Vivify"] = 116670,
				["SheilunsGift"] = 399491,
				["Lifecycles"] = 197915,
				["DiffuseMagic"] = 122783,
				["EnergizingBrew"] = 422031,
				["OverflowingMists"] = 388511,
				["CelestialHarmony"] = 343655,
				["MistWrap"] = 197900,
				["DanceoftheWind"] = 414132,
				["AncientConcordance"] = 388740,
				["ResplendentMist"] = 388020,
				["Chrysalis"] = 202424,
				["FocusedThunder"] = 197895,
				["SummonWhiteTigerStatue"] = 388686,
				["EchoingReverberation"] = 388604,
				["InvokeChi-Ji,theRedCrane"] = 325197,
				["ImprovedVivify"] = 231602,
				["RingofPeace"] = 116844,
				["TeaofSerenity"] = 393460,
				["Celerity"] = 115173,
				["VivaciousVivification"] = 388812,
				["FerocityofXuen"] = 388674,
				["Transcendence:Transfer"] = 119996,
				["Provoke"] = 115546,
				["AccumulatingMist"] = 388564,
				["ClosetoHeart"] = 389574,
				["TigerPalm"] = 100780,
				["Disable"] = 116095,
				["MistsofLife"] = 388548,
				["DampenHarm"] = 122278,
				["JadeBond"] = 388031,
				["Windwalking"] = 157411,
				["ImprovedTouchofDeath"] = 322113,
				["EyeoftheTiger"] = 196607,
				["ManaTea"] = 115294,
				["SecretInfusion"] = 388491,
				["HealingElixir"] = 122280,
				["SpearHandStrike"] = 116705,
				["FastFeet"] = 388809,
				["Unison"] = 388477,
				["EscapefromReality"] = 394110,
				["ChiBurst"] = 123986,
				["Mastery:GustofMists"] = 117907,
				["YulonsGrace"] = 414131,
				["BlackoutKick"] = 100784,
				["RisingSunKick"] = 107428,
				["LifeCocoon"] = 116849,
				["AncientTeachings"] = 388023,
				["LegSweep"] = 119381,
				["RisingMist"] = 274909,
				["ImprovedDetox"] = 388874,
				["SummonJadeSerpentStatue"] = 115313,
				["Detox"] = 115450,
				["RapidDiffusion"] = 388847,
				["FatalTouch"] = 394123,
				["ZenPilgrimage"] = 126892,
				["HastyProvocation"] = 328670,
				["BounceBack"] = 389577,
				["SpinningCraneKick"] = 101546,
				["ZenFlight"] = 125883,
			},
			["Brewmaster"] = {
				["CalmingPresence"] = 388664,
				["GracefulExit"] = 387256,
				["GenerousPour"] = 389575,
				["CelestialBrew"] = 322507,
				["MysticTouch"] = 8647,
				["FortifyingBrew"] = 115203,
				["ImprovedParalysis"] = 344359,
				["ElusiveMists"] = 388681,
				["HighTolerance"] = 196737,
				["HealingElixir"] = 122281,
				["KegSmash"] = 121253,
				["IronshellBrew"] = 388814,
				["CelestialFlames"] = 325177,
				["VivaciousVivification"] = 388812,
				["ZenPilgrimage"] = 126892,
				["ResonantFists"] = 389578,
				["QuickSip"] = 388505,
				["CharredPassions"] = 386965,
				["StrengthofSpirit"] = 387276,
				["ProfoundRebuttal"] = 392910,
				["Paralysis"] = 115078,
				["Transcendence"] = 101643,
				["CracklingJadeLightning"] = 117952,
				["DanceoftheWind"] = 414132,
				["FortifyingBrew:Determination"] = 322960,
				["SaveThemAll"] = 389579,
				["GraceoftheCrane"] = 388811,
				["BobandWeave"] = 280515,
				["SoothingMist"] = 115175,
				["EyeoftheTiger"] = 196607,
				["CalltoArms"] = 397251,
				["ImprovedCelestialBrew"] = 322510,
				["Roll"] = 109132,
				["CelestialFortune"] = 216519,
				["Detox"] = 218164,
				["Windwalking"] = 157411,
				["ScaldingBrew"] = 383698,
				["ZenMeditation"] = 115176,
				["ImprovedRoll"] = 328669,
				["Attenuation"] = 386941,
				["ImprovedPurifyingBrew"] = 343743,
				["ChiWave"] = 115098,
				["BlackOxBrew"] = 115399,
				["DragonfireBrew"] = 383994,
				["TouchofDeath"] = 322109,
				["GaiPlinsImperialBrew"] = 383700,
				["Stagger"] = 115069,
				["RushingJadeWind"] = 116847,
				["ExpeditiousFortification"] = 388813,
				["DiffuseMagic"] = 122783,
				["ExpelHarm"] = 322101,
				["LegSweep"] = 119381,
				["SongofChi-Ji"] = 198898,
				["BonedustBrew"] = 386276,
				["SpiritoftheOx"] = 400629,
				["ChiTorpedo"] = 115008,
				["Resuscitate"] = 115178,
				["BlackoutCombo"] = 196736,
				["Clash"] = 324312,
				["Vivify"] = 116670,
				["SummonWhiteTigerStatue"] = 388686,
				["HitScheme"] = 383695,
				["RingofPeace"] = 116844,
				["RisingSunKick"] = 107428,
				["TigersLust"] = 116841,
				["WalkwiththeOx"] = 387219,
				["FluidityofMotion"] = 387230,
				["ExplodingKeg"] = 325153,
				["ImprovedInvokeNiuzao,theBlackOx"] = 322740,
				["Mastery:ElusiveBrawler"] = 117906,
				["TigerTailSweep"] = 264348,
				["WeaponsofOrder"] = 387184,
				["InvokeNiuzao,theBlackOx"] = 132578,
				["GiftoftheOx"] = 124502,
				["FacePalm"] = 389942,
				["Counterstrike"] = 383785,
				["ChiSurge"] = 393400,
				["Celerity"] = 115173,
				["SpearHandStrike"] = 116705,
				["FerocityofXuen"] = 388674,
				["Transcendence:Transfer"] = 119996,
				["Provoke"] = 115546,
				["SummonBlackOxStatue"] = 115315,
				["ClosetoHeart"] = 389574,
				["FastFeet"] = 388809,
				["Disable"] = 116095,
				["ChiBurst"] = 123986,
				["DampenHarm"] = 122278,
				["Shuffle"] = 322120,
				["VigorousExpulsion"] = 392900,
				["ImprovedTouchofDeath"] = 322113,
				["Anvil&Stave"] = 386937,
				["SummonJadeSerpentStatue"] = 115313,
				["PurifyingBrew"] = 119582,
				["StaggeringStrikes"] = 387625,
				["TranquilSpirit"] = 393357,
				["SpecialDelivery"] = 196730,
				["ElusiveFootwork"] = 387046,
				["EscapefromReality"] = 394110,
				["StormstoutsLastKeg"] = 383707,
				["ShadowboxingTreads"] = 387638,
				["YulonsGrace"] = 414131,
				["BlackoutKick"] = 205523,
				["PretenseofInstability"] = 393516,
				["BrewmastersBalance"] = 245013,
				["FundamentalObservation"] = 387035,
				["SalsalabimsStrength"] = 383697,
				["BreathofFire"] = 115181,
				["ImprovedVivify"] = 231602,
				["PresstheAdvantage"] = 418359,
				["BountifulBrew"] = 386949,
				["TrainingofNiuzao"] = 383714,
				["FatalTouch"] = 394123,
				["LightBrewing"] = 325093,
				["HastyProvocation"] = 328670,
				["BounceBack"] = 389577,
				["SpinningCraneKick"] = 322729,
				["ZenFlight"] = 125883,
			},
			["Windwalker"] = {
				["CalmingPresence"] = 388664,
				["GenerousPour"] = 389575,
				["FaelineHarmony"] = 391412,
				["MarkoftheCrane"] = 220357,
				["Skyreach"] = 392991,
				["FortifyingBrew"] = 115203,
				["RisingStar"] = 388849,
				["Ascension"] = 115396,
				["ElusiveMists"] = 388681,
				["Transcendence"] = 101643,
				["DrinkingHornCover"] = 391370,
				["XuensBond"] = 392986,
				["Serenity"] = 152173,
				["InvokersDelight"] = 388661,
				["Thunderfist"] = 392985,
				["ProfoundRebuttal"] = 392910,
				["TouchoftheTiger"] = 388856,
				["DanceoftheWind"] = 414132,
				["TouchofKarma"] = 122470,
				["ZenPilgrimage"] = 126892,
				["FaelineStomp"] = 388193,
				["WayoftheFae"] = 392994,
				["SoothingMist"] = 115175,
				["EyeoftheTiger"] = 196607,
				["Paralysis"] = 115078,
				["TigerTailSweep"] = 264348,
				["CraneVortex"] = 388848,
				["TransferthePower"] = 195300,
				["CracklingJadeLightning"] = 117952,
				["Windwalking"] = 157411,
				["MysticTouch"] = 8647,
				["StrengthofSpirit"] = 387276,
				["ImprovedRoll"] = 328669,
				["Attenuation"] = 386941,
				["HardenedSoles"] = 391383,
				["WideningWhirl"] = 388846,
				["VigorousExpulsion"] = 392900,
				["DanceofChi-Ji"] = 325201,
				["Afterlife"] = 116092,
				["SummonBlackOxStatue"] = 115315,
				["TeachingsoftheMonastery"] = 116645,
				["RushingJadeWind"] = 116847,
				["ExpeditiousFortification"] = 388813,
				["JadeIgnition"] = 392979,
				["ExpelHarm"] = 322101,
				["LegSweep"] = 119381,
				["SongofChi-Ji"] = 198898,
				["ChiBurst"] = 123986,
				["TouchofDeath"] = 322109,
				["ChiTorpedo"] = 115008,
				["Resuscitate"] = 115178,
				["WhirlingDragonPunch"] = 152175,
				["XuensBattlegear"] = 392993,
				["Vivify"] = 116670,
				["StrikeoftheWindlord"] = 392983,
				["ChiWave"] = 115098,
				["RingofPeace"] = 116844,
				["OpenPalmStrikes"] = 392970,
				["IronshellBrew"] = 388814,
				["TigersLust"] = 116841,
				["ForbiddenTechnique"] = 393098,
				["SpiritualFocus"] = 280197,
				["EmpoweredTigerLightning"] = 323999,
				["FlashingFists"] = 388854,
				["FuryofXuen"] = 396166,
				["LastEmperorsCapacitor"] = 392989,
				["FistsofFury"] = 113656,
				["Storm,Earth,andFire"] = 137639,
				["GloryoftheDawn"] = 392958,
				["BonedustBrew"] = 386276,
				["SummonWhiteTigerStatue"] = 388686,
				["Celerity"] = 115173,
				["Skytouch"] = 405044,
				["FlyingSerpentKick"] = 101545,
				["Transcendence:Transfer"] = 119996,
				["Provoke"] = 115546,
				["SpearHandStrike"] = 116705,
				["ClosetoHeart"] = 389574,
				["ImprovedParalysis"] = 344359,
				["Disable"] = 116095,
				["MeridianStrikes"] = 391330,
				["DampenHarm"] = 122278,
				["VivaciousVivification"] = 388812,
				["FastFeet"] = 388809,
				["Mastery:ComboStrikes"] = 115636,
				["ImprovedTouchofDeath"] = 322113,
				["Detox"] = 218164,
				["DiffuseMagic"] = 122783,
				["FatalFlyingGuillotine"] = 394923,
				["DustintheWind"] = 394093,
				["FerocityofXuen"] = 388674,
				["TigerPalm"] = 100780,
				["EscapefromReality"] = 394110,
				["ResonantFists"] = 389578,
				["ShadowboxingTreads"] = 392982,
				["YulonsGrace"] = 414131,
				["BlackoutKick"] = 100784,
				["RisingSunKick"] = 107428,
				["GraceoftheCrane"] = 388811,
				["SummonJadeSerpentStatue"] = 115313,
				["InvokeXuen,theWhiteTiger"] = 123904,
				["ImprovedVivify"] = 231602,
				["HitCombo"] = 196740,
				["InnerPeace"] = 397768,
				["SaveThemAll"] = 389579,
				["PowerStrikes"] = 121817,
				["FatalTouch"] = 394123,
				["Roll"] = 109132,
				["HastyProvocation"] = 328670,
				["BounceBack"] = 389577,
				["SpinningCraneKick"] = 101546,
				["ZenFlight"] = 125883,
			},
		},
		["Rogue"] = {
			["Outlaw"] = {
				["Ruthlessness"] = 14161,
				["Evasion"] = 5277,
				["KeepItRolling"] = 381989,
				["SuperiorMixture"] = 423701,
				["PickPocket"] = 921,
				["ImprovedMainGauche"] = 382746,
				["Featherfoot"] = 423683,
				["ShadowDance"] = 185313,
				["HeavyHitter"] = 381885,
				["FleetFooted"] = 378813,
				["BlindingPowder"] = 256165,
				["GracefulGuile"] = 423647,
				["EchoingReprimand"] = 385616,
				["Blind"] = 2094,
				["PistolShot"] = 185763,
				["DirtyTricks"] = 108216,
				["VirulentPoisons"] = 381543,
				["Audacity"] = 381845,
				["TakeembySurprise"] = 382742,
				["TripleThreat"] = 381894,
				["ImprovedAdrenalineRush"] = 395422,
				["TightSpender"] = 381621,
				["ThistleTea"] = 381623,
				["Mastery:MainGauche"] = 76806,
				["CheapShot"] = 1833,
				["ColdBlood"] = 382245,
				["GrapplingHook"] = 195457,
				["Nightstalker"] = 14062,
				["BetweentheEyes"] = 315341,
				["ResoundingClarity"] = 381622,
				["BladeFlurry"] = 13877,
				["HitandRun"] = 196922,
				["SafeFall"] = 1860,
				["Ambidexterity"] = 381822,
				["RetractableHook"] = 256188,
				["Kick"] = 1766,
				["SummarilyDispatched"] = 381990,
				["NimbleFingers"] = 378427,
				["Stealth"] = 115191,
				["TricksoftheTrade"] = 57934,
				["ImprovedAmbush"] = 381620,
				["Shiv"] = 5938,
				["Sepsis"] = 385408,
				["BladeRush"] = 271877,
				["AcrobaticStrikes"] = 196924,
				["SliceandDice"] = 315496,
				["SinisterStrike"] = 193315,
				["Sap"] = 6770,
				["ShroudofConcealment"] = 114018,
				["Alacrity"] = 193539,
				["DeftManeuvers"] = 381878,
				["PickLock"] = 1804,
				["KidneyShot"] = 408,
				["SleightofHand"] = 381839,
				["Vanish"] = 1856,
				["StingLikeaBee"] = 131511,
				["Feint"] = 1966,
				["AceUpYourSleeve"] = 381828,
				["SoothingDarkness"] = 393970,
				["ImprovedSprint"] = 231691,
				["Detection"] = 56814,
				["CrimsonVial"] = 185311,
				["DeadlyPrecision"] = 381542,
				["GhostlyStrike"] = 196937,
				["Reverberation"] = 394332,
				["KillingSpree"] = 51690,
				["Crackshot"] = 423703,
				["AdrenalineRush"] = 13750,
				["AtrophicPoison"] = 381637,
				["NumbingPoison"] = 5761,
				["Ambush"] = 8676,
				["Vigor"] = 14983,
				["LeechingPoison"] = 280716,
				["CloakofShadows"] = 31224,
				["Lethality"] = 382238,
				["RestlessBlades"] = 79096,
				["GreenskinsWickers"] = 386823,
				["RushedSetup"] = 378803,
				["FloatLikeaButterfly"] = 354897,
				["Blackjack"] = 379005,
				["MasterPoisoner"] = 378436,
				["DancingSteel"] = 272026,
				["AirborneIrritant"] = 200733,
				["ImprovedWoundPoison"] = 319066,
				["ImprovedBetweentheEyes"] = 235484,
				["Sprint"] = 2983,
				["RolltheBones"] = 315508,
				["UnbreakableStride"] = 400804,
				["Recuperator"] = 378996,
				["DeeperStratagem"] = 193531,
				["IronStomach"] = 193546,
				["CheatDeath"] = 31230,
				["Riposte"] = 344363,
				["SwiftSlasher"] = 381988,
				["Shadowstep"] = 36554,
				["Stillshroud"] = 423662,
				["PrecisionShot"] = 428377,
				["Dispatch"] = 2098,
				["Elusiveness"] = 79008,
				["DeadenedNerves"] = 231719,
				["DeviousStratagem"] = 394321,
				["PreciseCuts"] = 381985,
				["LoadedDice"] = 256170,
				["QuickDraw"] = 196938,
				["CombatPotency"] = 61329,
				["Gouge"] = 1776,
				["FatalFlourish"] = 35551,
				["CombatStamina"] = 381877,
				["Distract"] = 1725,
				["CounttheOdds"] = 381982,
				["Subterfuge"] = 108208,
				["Opportunity"] = 279876,
				["Shadowrunner"] = 378807,
				["ThiefsVersatility"] = 381619,
				["UnderhandedUpperHand"] = 424044,
				["FantheHammer"] = 381846,
				["HiddenOpportunity"] = 383281,
			},
			["Subtlety"] = {
				["Inevitability"] = 382512,
				["Evasion"] = 5277,
				["SuperiorMixture"] = 423701,
				["ImprovedShurikenStorm"] = 319951,
				["Featherfoot"] = 423683,
				["ShadowDance"] = 185313,
				["FleetFooted"] = 378813,
				["DarkBrew"] = 382504,
				["Kick"] = 1766,
				["Finality"] = 382525,
				["Subterfuge"] = 108208,
				["Blind"] = 2094,
				["UnbreakableStride"] = 400804,
				["Elusiveness"] = 79008,
				["TerrifyingPace"] = 428387,
				["Weaponmaster"] = 193537,
				["VirulentPoisons"] = 381543,
				["Vigor"] = 14983,
				["Detection"] = 56814,
				["DeadlyPrecision"] = 381542,
				["ExhilaratingExecution"] = 428486,
				["Veiltouched"] = 382017,
				["Stealth"] = 1784,
				["TightSpender"] = 381621,
				["Shadowstrike"] = 185438,
				["GoremawsBite"] = 426591,
				["AcrobaticStrikes"] = 196924,
				["BlackPowder"] = 319175,
				["CheapShot"] = 1833,
				["Backstab"] = 53,
				["SafeFall"] = 1860,
				["ShurikenToss"] = 114014,
				["Sprint"] = 2983,
				["PerforatedVeins"] = 382518,
				["DanseMacabre"] = 382528,
				["ShroudofConcealment"] = 114018,
				["WithoutaTrace"] = 382513,
				["ShadowTechniques"] = 196912,
				["CheatDeath"] = 31230,
				["ShadowBlades"] = 121471,
				["PickPocket"] = 921,
				["CloakedinShadows"] = 382515,
				["TheRotten"] = 382015,
				["SwiftDeath"] = 394309,
				["ImprovedAmbush"] = 381620,
				["EphemeralBond"] = 426563,
				["ShotintheDark"] = 257505,
				["PickLock"] = 1804,
				["ReplicatingShadows"] = 382506,
				["Flagellation"] = 384631,
				["KidneyShot"] = 408,
				["Sap"] = 6770,
				["Feint"] = 1966,
				["Alacrity"] = 193539,
				["ImprovedShadowTechniques"] = 394023,
				["DeepeningShadows"] = 185314,
				["Distract"] = 1725,
				["ThistleTea"] = 381623,
				["Vanish"] = 1856,
				["CrimsonVial"] = 185311,
				["SymbolsofDeath"] = 212283,
				["NimbleFingers"] = 378427,
				["GracefulGuile"] = 423647,
				["ImprovedSprint"] = 231691,
				["ShurikenTornado"] = 277925,
				["Stillshroud"] = 423662,
				["AtrophicPoison"] = 381637,
				["Rupture"] = 1943,
				["Reverberation"] = 394332,
				["LeechingPoison"] = 280716,
				["FadetoNothing"] = 382514,
				["Gloomblade"] = 200758,
				["RushedSetup"] = 378803,
				["NumbingPoison"] = 5761,
				["ImprovedBackstab"] = 319949,
				["Lethality"] = 382238,
				["ColdBlood"] = 382245,
				["SecretTechnique"] = 280719,
				["WarningSigns"] = 426555,
				["Mastery:Executioner"] = 76808,
				["SoothingDarkness"] = 393970,
				["ShadowFocus"] = 108209,
				["Shadowcraft"] = 426594,
				["IronStomach"] = 193546,
				["MasterPoisoner"] = 378436,
				["Nightstalker"] = 14062,
				["AirborneIrritant"] = 200733,
				["ImprovedWoundPoison"] = 319066,
				["ImprovedShadowDance"] = 393972,
				["NightTerrors"] = 277953,
				["ShurikenStorm"] = 197835,
				["Shiv"] = 5938,
				["Recuperator"] = 378996,
				["DeeperStratagem"] = 193531,
				["DarkShadow"] = 245687,
				["TheFirstDance"] = 382505,
				["PlannedExecution"] = 382508,
				["Eviscerate"] = 196819,
				["Shadowstep"] = 36554,
				["InvigoratingShadowdust"] = 382523,
				["QuickDecisions"] = 382503,
				["MasterofShadows"] = 196976,
				["RelentlessStrikes"] = 58423,
				["DeadenedNerves"] = 231719,
				["EchoingReprimand"] = 385616,
				["CloakofShadows"] = 31224,
				["DeeperDaggers"] = 382517,
				["ShadowedFinishers"] = 382511,
				["SliceandDice"] = 315496,
				["Gouge"] = 1776,
				["FindWeakness"] = 91023,
				["TricksoftheTrade"] = 57934,
				["LingeringShadow"] = 382524,
				["Blackjack"] = 379005,
				["Premeditation"] = 343160,
				["SecretStratagem"] = 394320,
				["ResoundingClarity"] = 381622,
				["ShroudedinDarkness"] = 382507,
				["SilentStorm"] = 385722,
				["Shadowrunner"] = 378807,
				["Sepsis"] = 385408,
			},
			["Assassination"] = {
				["AtrophicPoison"] = 381637,
				["Evasion"] = 5277,
				["SystemicFailure"] = 381652,
				["SuperiorMixture"] = 423701,
				["PickPocket"] = 921,
				["VenomRush"] = 152152,
				["Featherfoot"] = 423683,
				["ShadowDance"] = 185313,
				["CuttotheChase"] = 51667,
				["FleetFooted"] = 378813,
				["BloodyMess"] = 381626,
				["GracefulGuile"] = 423647,
				["Subterfuge"] = 108208,
				["Blind"] = 2094,
				["LethalDose"] = 381640,
				["VirulentPoisons"] = 381543,
				["Vigor"] = 14983,
				["SealFate"] = 14190,
				["FlyingDaggers"] = 381631,
				["Stealth"] = 1784,
				["TightSpender"] = 381621,
				["IronWire"] = 196861,
				["PoisonedKnife"] = 185565,
				["CheapShot"] = 1833,
				["ThrownPrecision"] = 381629,
				["ScentofBlood"] = 381799,
				["ResoundingClarity"] = 381622,
				["Mastery:PotentAssassin"] = 76803,
				["CausticSpatter"] = 421975,
				["SerratedBoneSpike"] = 385424,
				["CheatDeath"] = 31230,
				["ImprovedGarrote"] = 381632,
				["Rupture"] = 1943,
				["NimbleFingers"] = 378427,
				["CrimsonVial"] = 185311,
				["Shadowrunner"] = 378807,
				["ImprovedAmbush"] = 381620,
				["AmplifyingPoison"] = 381664,
				["Sepsis"] = 385408,
				["DashingScoundrel"] = 381797,
				["AcrobaticStrikes"] = 196924,
				["Kingsbane"] = 385627,
				["IronStomach"] = 193546,
				["Sap"] = 6770,
				["ShroudedSuffocation"] = 385478,
				["Alacrity"] = 193539,
				["ZoldyckRecipe"] = 381798,
				["Envenom"] = 32645,
				["ImprovedShiv"] = 319032,
				["ThistleTea"] = 381623,
				["Vanish"] = 1856,
				["SafeFall"] = 1860,
				["Garrote"] = 703,
				["Deathmark"] = 360194,
				["ShroudofConcealment"] = 114018,
				["ImprovedSprint"] = 231691,
				["PickLock"] = 1804,
				["KidneyShot"] = 408,
				["Kick"] = 1766,
				["LightweightShiv"] = 394983,
				["UnbreakableStride"] = 400804,
				["FatalConcoction"] = 392384,
				["Feint"] = 1966,
				["Gouge"] = 1776,
				["ImprovedPoisons"] = 381624,
				["NumbingPoison"] = 5761,
				["Ambush"] = 8676,
				["TwisttheKnife"] = 381669,
				["Mutilate"] = 1329,
				["CloakofShadows"] = 31224,
				["Lethality"] = 382238,
				["Stillshroud"] = 423662,
				["SoothingDarkness"] = 393970,
				["RushedSetup"] = 378803,
				["ImprovedWoundPoison"] = 319066,
				["IntenttoKill"] = 381630,
				["MasterPoisoner"] = 378436,
				["Nightstalker"] = 14062,
				["AirborneIrritant"] = 200733,
				["ColdBlood"] = 382245,
				["TinyToxicBlade"] = 381800,
				["Sprint"] = 2983,
				["EchoingReprimand"] = 385616,
				["PathofBlood"] = 423054,
				["Recuperator"] = 378996,
				["DeeperStratagem"] = 193531,
				["Blindside"] = 328085,
				["ArterialPrecision"] = 400783,
				["DeadlyPoison"] = 2823,
				["PoisonBomb"] = 255544,
				["Shadowstep"] = 36554,
				["MasterAssassin"] = 255989,
				["SanguineBlades"] = 200806,
				["Doomblade"] = 381673,
				["Elusiveness"] = 79008,
				["DeadenedNerves"] = 231719,
				["IndiscriminateCarnage"] = 381802,
				["ViciousVenoms"] = 381634,
				["Dragon-TemperedBlades"] = 381801,
				["CrimsonTempest"] = 121411,
				["SliceandDice"] = 315496,
				["LeechingPoison"] = 280716,
				["Detection"] = 56814,
				["Reverberation"] = 394332,
				["Distract"] = 1725,
				["Blackjack"] = 379005,
				["SuddenDemise"] = 423136,
				["DeadlyPrecision"] = 381542,
				["InternalBleeding"] = 381627,
				["VenomousWounds"] = 79134,
				["Shiv"] = 5938,
				["FanofKnives"] = 51723,
				["TricksoftheTrade"] = 57934,
			},
		},
		["Mage"] = {
			["Frost"] = {
				["FracturedFrost"] = 378448,
				["RemoveCurse"] = 475,
				["TomeofAntonidas"] = 382490,
				["TomeofRhonin"] = 382493,
				["Polymorph"] = 118,
				["DivertedEnergy"] = 382270,
				["Flurry"] = 44614,
				["IncantationofSwiftness"] = 382293,
				["BrainFreeze"] = 190447,
				["PiercingCold"] = 378919,
				["RigidIce"] = 382481,
				["SplinteringRay"] = 418733,
				["ArcaneWarding"] = 383092,
				["RayofFrost"] = 205021,
				["TimeManipulation"] = 387807,
				["DragonsBreath"] = 31661,
				["IceCold"] = 414658,
				["Cryo-Freeze"] = 382292,
				["Spellsteal"] = 30449,
				["GlacialAssault"] = 378947,
				["IceBarrier"] = 11426,
				["Shatter"] = 12982,
				["IceNova"] = 157997,
				["PerpetualWinter"] = 378198,
				["Slow"] = 31589,
				["OverflowingEnergy"] = 390218,
				["SlickIce"] = 382144,
				["MasterofTime"] = 342249,
				["SplinteringCold"] = 379049,
				["FireBlast"] = 319836,
				["FrigidWinds"] = 235224,
				["ColdestSnap"] = 417493,
				["SlowFall"] = 130,
				["IceFloes"] = 108839,
				["Blizzard"] = 190356,
				["FlowofTime"] = 382268,
				["FrostNova"] = 122,
				["Counterspell"] = 2139,
				["VolatileDetonation"] = 389627,
				["ConjureRefreshment"] = 190336,
				["Reabsorption"] = 382820,
				["TimeAnomaly"] = 383243,
				["ArcaneIntellect"] = 1459,
				["DeepShatter"] = 378749,
				["LonelyWinter"] = 205024,
				["ColdSnap"] = 235219,
				["QuickWitted"] = 382297,
				["RingofFrost"] = 113724,
				["FrozenTouch"] = 205030,
				["IceWard"] = 205036,
				["IncantersFlow"] = 1463,
				["Subzero"] = 380154,
				["MassBarrier"] = 414660,
				["ArcaneExplosion"] = 1449,
				["ShiftingPower"] = 382440,
				["WintersBlessing"] = 417489,
				["TemporalWarp"] = 386539,
				["GreaterInvisibility"] = 110959,
				["EverlastingFrost"] = 385167,
				["FreezingRain"] = 270233,
				["Cryopathy"] = 417491,
				["Frostbite"] = 378756,
				["TemporalVelocity"] = 382826,
				["CometStorm"] = 153595,
				["FrozenOrb"] = 84714,
				["Wintertide"] = 378406,
				["IceLance"] = 30455,
				["Reduplication"] = 382569,
				["ImprovedFrostNova"] = 343183,
				["IcyVeins"] = 12472,
				["ConeofCold"] = 120,
				["FreezingWinds"] = 382103,
				["MassInvisibility"] = 414664,
				["Frostbolt"] = 116,
				["Snowstorm"] = 381706,
				["GlacialSpike"] = 199786,
				["Mastery:Icicles"] = 76613,
				["TimeWarp"] = 80353,
				["FlashFreeze"] = 379993,
				["MirrorImage"] = 55342,
				["FingersofFrost"] = 112965,
				["AccumulativeShielding"] = 382800,
				["AlterTime"] = 342245,
				["Hailstones"] = 381244,
				["SplittingIce"] = 56377,
				["ThermalVoid"] = 155149,
				["IceBlock"] = 45438,
				["ChainReaction"] = 278309,
				["MassPolymorph"] = 383121,
				["TempestBarrier"] = 382289,
				["ColdFront"] = 382110,
				["BlastWave"] = 157981,
				["BoneChilling"] = 205027,
				["IceCaller"] = 236662,
				["FreezingCold"] = 386763,
				["Shimmer"] = 212653,
				["MassSlow"] = 391102,
				["WintersProtection"] = 382424,
				["EnergizedBarriers"] = 386828,
				["Displacement"] = 389713,
			},
			["Fire"] = {
				["RemoveCurse"] = 475,
				["TomeofAntonidas"] = 382490,
				["TomeofRhonin"] = 382493,
				["CriticalMass"] = 117216,
				["Polymorph"] = 118,
				["DivertedEnergy"] = 382270,
				["IncantationofSwiftness"] = 382293,
				["DeepImpact"] = 416719,
				["FeeltheBurn"] = 383391,
				["RigidIce"] = 382481,
				["TempestBarrier"] = 382289,
				["ArcaneWarding"] = 383092,
				["Hyperthermia"] = 383860,
				["TimeManipulation"] = 387807,
				["DragonsBreath"] = 31661,
				["AlexstraszasFury"] = 235870,
				["IceCold"] = 414659,
				["Cryo-Freeze"] = 382292,
				["BlastWave"] = 157981,
				["ImprovedScorch"] = 383604,
				["Conflagration"] = 205023,
				["Pyromaniac"] = 205020,
				["FueltheFire"] = 416094,
				["MirrorImage"] = 55342,
				["Meteor"] = 153561,
				["SunKingsBlessing"] = 383886,
				["ConjureRefreshment"] = 190336,
				["Slow"] = 31589,
				["OverflowingEnergy"] = 390218,
				["MasterofFlame"] = 384174,
				["MasterofTime"] = 342249,
				["HotStreak"] = 195283,
				["Pyrotechnics"] = 157642,
				["SearingTouch"] = 269644,
				["Fireball"] = 133,
				["FireBlast"] = 108853,
				["FlowofTime"] = 382268,
				["FlamePatch"] = 205037,
				["IceBlock"] = 45438,
				["SlowFall"] = 130,
				["IceFloes"] = 108839,
				["TemperedFlames"] = 383659,
				["EnergizedBarriers"] = 386828,
				["Invisibility"] = 66,
				["Cauterize"] = 86949,
				["VolatileDetonation"] = 389627,
				["Kindling"] = 155148,
				["Reabsorption"] = 382820,
				["TimeAnomaly"] = 383243,
				["FrostNova"] = 122,
				["Counterspell"] = 2139,
				["ArcaneIntellect"] = 1459,
				["Pyroblast"] = 11366,
				["QuickWitted"] = 382297,
				["BlazingBarrier"] = 235313,
				["Firemind"] = 383499,
				["IceWard"] = 205036,
				["IncantersFlow"] = 1463,
				["ArcaneExplosion"] = 1449,
				["MassBarrier"] = 414660,
				["Inflame"] = 417467,
				["ShiftingPower"] = 382440,
				["Convection"] = 416715,
				["TemporalWarp"] = 386539,
				["Combustion"] = 190319,
				["Mastery:Ignite"] = 12846,
				["FromtheAshes"] = 342344,
				["TemporalVelocity"] = 382826,
				["GreaterInvisibility"] = 110959,
				["MassPolymorph"] = 383121,
				["CalloftheSunKing"] = 343222,
				["PhoenixFlames"] = 257541,
				["PhoenixReborn"] = 383476,
				["Scorch"] = 2948,
				["Reduplication"] = 382569,
				["ImprovedFrostNova"] = 343183,
				["FeveredIncantation"] = 383810,
				["ConeofCold"] = 120,
				["IntensifyingFlame"] = 416714,
				["MassInvisibility"] = 414664,
				["Frostbolt"] = 116,
				["Firestarter"] = 205026,
				["Wildfire"] = 383489,
				["FieryRush"] = 383634,
				["TimeWarp"] = 80353,
				["UnleashedInferno"] = 416506,
				["AccumulativeShielding"] = 382800,
				["FlameAccelerant"] = 203275,
				["Flamestrike"] = 2120,
				["AlterTime"] = 342245,
				["Firefall"] = 384033,
				["RingofFrost"] = 113724,
				["FrigidWinds"] = 235224,
				["FerventFlickering"] = 387044,
				["LivingBomb"] = 44457,
				["SurgingBlaze"] = 343230,
				["FlameOn"] = 205029,
				["IncendiaryEruptions"] = 383665,
				["Spellsteal"] = 30449,
				["IceNova"] = 157997,
				["ControlledDestruction"] = 383669,
				["FreezingCold"] = 386763,
				["Shimmer"] = 212653,
				["MassSlow"] = 391102,
				["ImprovedCombustion"] = 383967,
				["WintersProtection"] = 382424,
				["Displacement"] = 389713,
			},
			["Arcane"] = {
				["PresenceofMind"] = 205025,
				["RemoveCurse"] = 475,
				["TomeofAntonidas"] = 382490,
				["TomeofRhonin"] = 382493,
				["ArcaneFamiliar"] = 205022,
				["Polymorph"] = 118,
				["DivertedEnergy"] = 382270,
				["OrbBarrage"] = 384858,
				["RuleofThrees"] = 264354,
				["IncantationofSwiftness"] = 382293,
				["ArcaneBlast"] = 30451,
				["ProdigiousSavant"] = 384612,
				["RigidIce"] = 382481,
				["TempestBarrier"] = 382289,
				["ArcaneWarding"] = 383092,
				["NetherTempest"] = 114923,
				["TimeManipulation"] = 387807,
				["DragonsBreath"] = 31661,
				["IceCold"] = 414659,
				["Cryo-Freeze"] = 382292,
				["Spellsteal"] = 30449,
				["ChronoShift"] = 235711,
				["ChargedOrb"] = 384651,
				["IceNova"] = 157997,
				["Concentration"] = 384374,
				["ArcaneHarmony"] = 384452,
				["Slow"] = 31589,
				["OverflowingEnergy"] = 390218,
				["ArcaneMissiles"] = 5143,
				["IlluminatedThoughts"] = 384060,
				["MasterofTime"] = 342249,
				["Enlightened"] = 321387,
				["ArcaneSurge"] = 365350,
				["FireBlast"] = 319836,
				["ManaAdept"] = 321526,
				["FrigidWinds"] = 235224,
				["IceBlock"] = 45438,
				["NetherPrecision"] = 383782,
				["IceFloes"] = 108839,
				["FlowofTime"] = 382268,
				["Supernova"] = 157980,
				["Amplification"] = 236628,
				["VolatileDetonation"] = 389627,
				["SlowFall"] = 130,
				["Evocation"] = 12051,
				["TimeAnomaly"] = 383243,
				["ArcingCleave"] = 231564,
				["Reverberate"] = 281482,
				["TouchoftheMagi"] = 321507,
				["ArcaneBarrage"] = 44425,
				["QuickWitted"] = 382297,
				["RingofFrost"] = 113724,
				["CascadingPower"] = 384276,
				["IceWard"] = 205036,
				["IncantersFlow"] = 1463,
				["Mastery:Savant"] = 190740,
				["MassBarrier"] = 414660,
				["Counterspell"] = 2139,
				["ShiftingPower"] = 382440,
				["Clearcasting"] = 79684,
				["TemporalWarp"] = 386539,
				["ConjureRefreshment"] = 190336,
				["ImprovedClearcasting"] = 321420,
				["ArcaneIntellect"] = 1459,
				["TemporalVelocity"] = 382826,
				["PrismaticBarrier"] = 235450,
				["ArcaneExplosion"] = 1449,
				["GreaterInvisibility"] = 110959,
				["ArcaneOrb"] = 153626,
				["ConcentratedPower"] = 414379,
				["ImprovedArcaneMissiles"] = 383661,
				["Reduplication"] = 382569,
				["ImprovedFrostNova"] = 343183,
				["RadiantSpark"] = 376103,
				["ConeofCold"] = 120,
				["ArcaneBombardment"] = 384581,
				["ImprovedPrismaticBarrier"] = 321745,
				["Frostbolt"] = 116,
				["MassInvisibility"] = 414664,
				["CracklingEnergy"] = 321752,
				["TimeWarp"] = 80353,
				["Impetus"] = 383676,
				["Slipstream"] = 236457,
				["HarmonicEcho"] = 384683,
				["FrostNova"] = 122,
				["ConjureManaGem"] = 759,
				["AlterTime"] = 342245,
				["Resonance"] = 205028,
				["Invisibility"] = 66,
				["SiphonStorm"] = 384187,
				["AccumulativeShielding"] = 382800,
				["ArcaneTempo"] = 383980,
				["Foresight"] = 384861,
				["MassPolymorph"] = 383121,
				["WintersProtection"] = 382424,
				["BlastWave"] = 157981,
				["Reabsorption"] = 382820,
				["MirrorImage"] = 55342,
				["FreezingCold"] = 386763,
				["Shimmer"] = 212653,
				["MassSlow"] = 391102,
				["ArcaneEcho"] = 342231,
				["EnergizedBarriers"] = 386828,
				["Displacement"] = 389713,
			},
		},
		["Demon Hunter"] = {
			["Havoc"] = {
				["Inertia"] = 427640,
				["ElysianDecree"] = 390163,
				["CriticalChaos"] = 320413,
				["FelBarrage"] = 258925,
				["EssenceBreak"] = 258860,
				["PitchBlack"] = 389783,
				["TrailofRuin"] = 258881,
				["BurningWound"] = 391189,
				["Pursuit"] = 320654,
				["LooksCanKill"] = 320415,
				["UnboundChaos"] = 347461,
				["GrowingInferno"] = 390158,
				["FelEruption"] = 211881,
				["ShatteredSouls"] = 178940,
				["FuriousThrows"] = 393029,
				["ChaosStrike"] = 162794,
				["Blur"] = 198589,
				["MortalDance"] = 328725,
				["AuraofPain"] = 207347,
				["DemonHide"] = 428241,
				["DemonicAppetite"] = 206478,
				["DemonMuzzle"] = 388111,
				["DemonBlades"] = 203555,
				["BouncingGlaives"] = 320386,
				["ErraticFelheart"] = 391397,
				["Darkness"] = 196718,
				["ImprovedDisrupt"] = 320361,
				["AcceleratedBlade"] = 391275,
				["Netherwalk"] = 196555,
				["ShatteredRestoration"] = 389824,
				["ChaosBrand"] = 255260,
				["SwallowedAnger"] = 320313,
				["SpectralSight"] = 188501,
				["RestlessHunter"] = 390142,
				["Initiative"] = 388108,
				["BurningHatred"] = 320374,
				["VengefulRetreat"] = 198793,
				["VengefulBonds"] = 320635,
				["ImprovedChaosStrike"] = 343206,
				["ConsumeMagic"] = 278326,
				["AnyMeansNecessary"] = 388114,
				["BlindFury"] = 203550,
				["Demonic"] = 213410,
				["SoulSigils"] = 395446,
				["ImmolationAura"] = 258920,
				["ChampionoftheGlaive"] = 429211,
				["SoulRending"] = 204909,
				["ThrowGlaive"] = 185123,
				["FirstBlood"] = 206416,
				["LivebytheGlaive"] = 428607,
				["InnerDemon"] = 389693,
				["UnrestrainedFury"] = 320770,
				["DancingwithFate"] = 389978,
				["WilloftheIllidari"] = 389695,
				["IsolatedPrey"] = 388113,
				["CharredWarblades"] = 213010,
				["FelRush"] = 195072,
				["PreciseSigils"] = 389799,
				["CycleofHatred"] = 258887,
				["TheHunt"] = 370965,
				["RelentlessOnslaught"] = 389977,
				["Ragefire"] = 388107,
				["EyeBeam"] = 198013,
				["TacticalRetreat"] = 389688,
				["BladeDance"] = 188499,
				["AldrachiDesign"] = 391409,
				["LongNight"] = 389781,
				["IllidariKnowledge"] = 389696,
				["ShatteredDestiny"] = 388116,
				["Glide"] = 131347,
				["Soulscar"] = 388106,
				["QuickenedSigils"] = 209281,
				["Mastery:DemonicPresence"] = 185164,
				["RushofChaos"] = 320421,
				["SerratedGlaive"] = 390154,
				["ChaosTheory"] = 389687,
				["Momentum"] = 206476,
				["ChaoticDisposition"] = 428492,
				["DisruptingFury"] = 183782,
				["LostinDarkness"] = 389849,
				["FuriousGaze"] = 343311,
				["AFireInside"] = 427775,
				["DemonicWards"] = 278386,
				["KnowYourEnemy"] = 388118,
				["ChaoticTransformation"] = 388112,
				["MasteroftheGlaive"] = 389763,
				["DashofChaos"] = 427794,
				["Metamorphosis"] = 191427,
				["CollectiveAnguish"] = 390152,
				["ChaosFragments"] = 320412,
				["InsatiableHunger"] = 258876,
				["DesperateInstincts"] = 205411,
				["FlamesofFury"] = 389694,
				["Imprison"] = 217832,
				["ImprovedSigilofMisery"] = 320418,
				["GlaiveTempest"] = 342817,
				["ChaosNova"] = 179057,
				["InternalStruggle"] = 393822,
				["ScarsofSuffering"] = 428232,
				["Felblade"] = 232893,
				["InfernalArmor"] = 320331,
				["ImprovedFelRush"] = 343017,
				["FelfireHaste"] = 389846,
				["Disrupt"] = 183752,
				["SigilofMisery"] = 207684,
				["BlazingPath"] = 320416,
				["Torment"] = 185245,
				["SigilofFlame"] = 204596,
				["DoubleJump"] = 196055,
				["DeflectingDance"] = 427776,
			},
			["Vengeance"] = {
				["SigilofFlame"] = 204596,
				["ElysianDecree"] = 390163,
				["InfernalStrike"] = 189110,
				["Torment"] = 185245,
				["IlluminatedSigils"] = 428557,
				["Fracture"] = 263642,
				["CharredWarblades"] = 213010,
				["PerfectlyBalancedGlaive"] = 320387,
				["FieryBrand"] = 204021,
				["Pursuit"] = 320654,
				["ChainsofAnger"] = 389715,
				["Mastery:FelBlood"] = 203747,
				["SoulCarver"] = 207407,
				["VolatileFlameblood"] = 390808,
				["FieryDemise"] = 389220,
				["FelDevastation"] = 212084,
				["StoketheFlames"] = 393827,
				["CycleofBinding"] = 389718,
				["DemonMuzzle"] = 388111,
				["AuraofPain"] = 207347,
				["ShearFury"] = 389997,
				["BouncingGlaives"] = 320386,
				["SigilofSilence"] = 202137,
				["ImprovedDisrupt"] = 320361,
				["LastResort"] = 209258,
				["AscendingFlame"] = 428603,
				["CalcifiedSpikes"] = 389720,
				["SwallowedAnger"] = 320313,
				["SpectralSight"] = 188501,
				["Retaliation"] = 389729,
				["Disrupt"] = 183752,
				["DarkglareBoon"] = 389708,
				["SigilofMisery"] = 207684,
				["VengefulBonds"] = 320635,
				["Painbringer"] = 207387,
				["ConsumeMagic"] = 278326,
				["FeedtheDemon"] = 218612,
				["Soulmonger"] = 389711,
				["SoulRending"] = 204909,
				["SoulSigils"] = 395446,
				["ImmolationAura"] = 258920,
				["ChampionoftheGlaive"] = 429211,
				["MeteoricStrikes"] = 389724,
				["ThrowGlaive"] = 204157,
				["DisruptingFury"] = 183782,
				["LivebytheGlaive"] = 428607,
				["DemonSpikes"] = 203720,
				["CharredFlesh"] = 336639,
				["FeastofSouls"] = 207697,
				["RuinousBulwark"] = 326853,
				["SoulBarrier"] = 263648,
				["RevelinPain"] = 343014,
				["PreciseSigils"] = 389799,
				["FelfireHaste"] = 389846,
				["InternalStruggle"] = 393822,
				["VengefulRetreat"] = 198793,
				["SoulFurnace"] = 391165,
				["BurningAlive"] = 207739,
				["TheHunt"] = 370965,
				["FocusedCleave"] = 343207,
				["VoidReaver"] = 268175,
				["ImprovedSigilofMisery"] = 320418,
				["DeflectingSpikes"] = 321028,
				["IllidariKnowledge"] = 389696,
				["BulkExtraction"] = 320341,
				["Vulnerability"] = 389976,
				["AgonizingFlames"] = 207548,
				["Glide"] = 131347,
				["ExtendedSpikes"] = 389721,
				["RushofChaos"] = 320421,
				["FlamesofFury"] = 389694,
				["PitchBlack"] = 389783,
				["Soulcrush"] = 389985,
				["RoaringFire"] = 391178,
				["FelFlameFortification"] = 389705,
				["LostinDarkness"] = 389849,
				["ErraticFelheart"] = 391397,
				["ChaosNova"] = 179057,
				["DemonicWards"] = 203513,
				["SpiritBomb"] = 247454,
				["Fallout"] = 227174,
				["MasteroftheGlaive"] = 389763,
				["SoulCleave"] = 228477,
				["Metamorphosis"] = 187827,
				["CollectiveAnguish"] = 390152,
				["ChaosFragments"] = 320412,
				["WilloftheIllidari"] = 389695,
				["LongNight"] = 389781,
				["BurningBlood"] = 390213,
				["Imprison"] = 217832,
				["UnrestrainedFury"] = 320770,
				["QuickenedSigils"] = 209281,
				["Frailty"] = 389958,
				["Demonic"] = 213410,
				["ShatteredRestoration"] = 389824,
				["Felblade"] = 232893,
				["InfernalArmor"] = 320331,
				["AldrachiDesign"] = 391409,
				["Darkness"] = 196718,
				["DowninFlames"] = 389732,
				["ChaosBrand"] = 255260,
				["BlazingPath"] = 320416,
				["ThickSkin"] = 320380,
				["SigilofChains"] = 202138,
				["DoubleJump"] = 196055,
				["ShatteredSouls"] = 204254,
			},
		},
		["Evoker"] = {
			["Augmentation"] = {
				["SourceofMagic"] = 369459,
				["StretchTime"] = 410352,
				["MotesofPossibility"] = 409267,
				["TwinGuardian"] = 370888,
				["AspectsFavor"] = 407243,
				["ClobberingSweep"] = 375443,
				["Zephyr"] = 374227,
				["Tailwind"] = 375556,
				["InfernosBlessing"] = 410261,
				["EssenceAttunement"] = 375722,
				["EchoingStrike"] = 410784,
				["CauterizingFlame"] = 374251,
				["Prescience"] = 409311,
				["BlastFurnace"] = 375510,
				["PlottheFuture"] = 407866,
				["HoardedPower"] = 375796,
				["ObsidianBulwark"] = 375406,
				["BlessingoftheBronze"] = 364342,
				["AncientFlame"] = 369990,
				["SymbioticBloom"] = 410685,
				["BlisteringScales"] = 360827,
				["RegenerativeMagic"] = 387787,
				["SpatialParadox"] = 406732,
				["ImposingPresence"] = 371016,
				["AzureStrike"] = 362969,
				["FociofLife"] = 375574,
				["PermeatingChill"] = 370897,
				["PowerNexus"] = 369908,
				["Mastery:Timewalker"] = 406380,
				["MomentumShift"] = 408004,
				["EbonMight"] = 395152,
				["HeavyWingbeats"] = 368838,
				["FireBreath"] = 382266,
				["Tomorrow,Today"] = 412723,
				["PotentMana"] = 418101,
				["NourishingSands"] = 406041,
				["InterwovenThreads"] = 412713,
				["EssenceBurst"] = 396187,
				["MoltenBlood"] = 410643,
				["SleepWalk"] = 360806,
				["PerilousFate"] = 410253,
				["NaturalConvergence"] = 369913,
				["Landslide"] = 358385,
				["Unravel"] = 368432,
				["TemperedScales"] = 396571,
				["ProlongLife"] = 410687,
				["FireWithin"] = 375577,
				["FateMirror"] = 412774,
				["FuryoftheAspects"] = 390386,
				["RenewingBlaze"] = 374348,
				["ObsidianScales"] = 363916,
				["Overawe"] = 374346,
				["EnergizingFlame"] = 400006,
				["DraconicAttunements"] = 403208,
				["WallopingBlow"] = 387341,
				["Overlord"] = 410260,
				["BreathofEons"] = 403631,
				["TerroroftheSkies"] = 371032,
				["Exuberance"] = 375542,
				["BestowWeyrnstone"] = 408233,
				["SandsofTime"] = 395153,
				["ScarletAdaptation"] = 372469,
				["SeismicSlam"] = 408543,
				["ReactiveHide"] = 409329,
				["Hover"] = 358267,
				["VerdantEmbrace"] = 360995,
				["AttunedtotheDream"] = 376930,
				["DreamofSpring"] = 414969,
				["Geomancy"] = 410787,
				["Eruption"] = 395160,
				["TimeSpiral"] = 374968,
				["BountifulBloom"] = 370886,
				["TiptheScales"] = 370553,
				["InnateMagic"] = 375520,
				["ChronoWard"] = 409676,
				["Accretion"] = 407876,
				["Upheaval"] = 408092,
				["IgnitionRush"] = 408775,
				["Volcanism"] = 406904,
				["LushGrowth"] = 375561,
				["DefyFate"] = 404195,
				["LeapingFlames"] = 369939,
				["ExtendedFlight"] = 375517,
				["Enkindled"] = 375554,
				["AerialMastery"] = 365933,
				["ProtractedTalons"] = 369909,
				["OppressingRoar"] = 372048,
				["Expunge"] = 365585,
				["BlackAttunement"] = 403264,
				["ForgerofMountains"] = 375528,
				["EmeraldBlossom"] = 355913,
				["Panacea"] = 387761,
				["FontofMagic"] = 408083,
				["Rescue"] = 370665,
				["RicochetingPyroclast"] = 406659,
				["CloseasClutchmates"] = 396043,
				["InstinctiveArcana"] = 376164,
				["TimeSkip"] = 404977,
				["Recall"] = 371806,
				["Return"] = 361227,
				["DraconicLegacy"] = 376166,
				["Quell"] = 351338,
				["LivingFlame"] = 361469,
				["RegenerativeChitin"] = 406907,
				["UnyieldingDomain"] = 412733,
				["InherentResistance"] = 375544,
				["PupilofAlexstrasza"] = 407814,
				["Anachronism"] = 407869,
				["TectonicLocus"] = 408002,
				["Timelessness"] = 412710,
				["InnerRadiance"] = 386405,
				["BronzeAttunement"] = 403265,
			},
			["Devastation"] = {
				["FocusingIris"] = 386336,
				["TwinGuardian"] = 370888,
				["ArcaneIntensity"] = 375618,
				["ClobberingSweep"] = 375443,
				["Zephyr"] = 374227,
				["Tailwind"] = 375556,
				["EssenceAttunement"] = 375722,
				["ProtractedTalons"] = 369909,
				["ChargedBlast"] = 370455,
				["PowerSwell"] = 370839,
				["CauterizingFlame"] = 374251,
				["BlastFurnace"] = 375510,
				["Snapfire"] = 370783,
				["HoardedPower"] = 375796,
				["LayWaste"] = 371034,
				["ObsidianBulwark"] = 375406,
				["BlessingoftheBronze"] = 364342,
				["AncientFlame"] = 369990,
				["Iridescence"] = 370867,
				["InnerRadiance"] = 386405,
				["WallopingBlow"] = 387341,
				["Burnout"] = 375801,
				["EyeofInfinity"] = 411165,
				["DraconicLegacy"] = 376166,
				["FociofLife"] = 375574,
				["PermeatingChill"] = 370897,
				["PowerNexus"] = 369908,
				["Recall"] = 371806,
				["DeepBreath"] = 357210,
				["Firestorm"] = 368847,
				["TitanicWrath"] = 386272,
				["EssenceBurst"] = 359565,
				["SleepWalk"] = 360806,
				["EventHorizon"] = 411164,
				["NaturalConvergence"] = 369913,
				["RagingInferno"] = 405659,
				["Unravel"] = 368432,
				["TemperedScales"] = 396571,
				["AzureStrike"] = 362969,
				["FireBreath"] = 357208,
				["Pyre"] = 357211,
				["FuryoftheAspects"] = 390386,
				["RenewingBlaze"] = 374348,
				["ObsidianScales"] = 363916,
				["Overawe"] = 374346,
				["ArcaneVigor"] = 386342,
				["Landslide"] = 358385,
				["Mastery:Giantkiller"] = 362980,
				["RubyEmbers"] = 365937,
				["LivingFlame"] = 361469,
				["EternitysSpan"] = 375757,
				["InstinctiveArcana"] = 376164,
				["HonedAggression"] = 371038,
				["PotentMana"] = 418101,
				["Causality"] = 375777,
				["Hover"] = 358267,
				["EternitySurge"] = 359073,
				["Animosity"] = 375797,
				["VerdantEmbrace"] = 360995,
				["Exuberance"] = 375542,
				["EnergizingFlame"] = 400006,
				["ShatteringStar"] = 370452,
				["OnyxLegacy"] = 386348,
				["TimeSpiral"] = 374968,
				["RegenerativeMagic"] = 387787,
				["AzureEssenceBurst"] = 375721,
				["InnateMagic"] = 375520,
				["ScarletAdaptation"] = 372469,
				["Panacea"] = 387761,
				["Enkindled"] = 375554,
				["TiptheScales"] = 370553,
				["LeapingFlames"] = 369939,
				["LushGrowth"] = 375561,
				["BountifulBloom"] = 370886,
				["TerroroftheSkies"] = 371032,
				["ExtendedFlight"] = 375517,
				["Catalyze"] = 386283,
				["AerialMastery"] = 365933,
				["Volatility"] = 369089,
				["OppressingRoar"] = 372048,
				["ImposingPresence"] = 371016,
				["Dragonrage"] = 375087,
				["ForgerofMountains"] = 375528,
				["EmeraldBlossom"] = 355913,
				["Scintillation"] = 370821,
				["FontofMagic"] = 411212,
				["FireWithin"] = 375577,
				["Expunge"] = 365585,
				["Tyranny"] = 376888,
				["RubyEssenceBurst"] = 376872,
				["EngulfingBlaze"] = 370837,
				["SourceofMagic"] = 369459,
				["Return"] = 361227,
				["Rescue"] = 370665,
				["Quell"] = 351338,
				["EverburningFlame"] = 370819,
				["SpellweaversDominance"] = 370845,
				["AttunedtotheDream"] = 376930,
				["InherentResistance"] = 375544,
				["DenseEnergy"] = 370962,
				["HeavyWingbeats"] = 368838,
				["FeedtheFlames"] = 369846,
				["ImminentDestruction"] = 370781,
				["Disintegrate"] = 356995,
				["HeatWave"] = 375725,
			},
			["Preservation"] = {
				["Stasis"] = 370537,
				["Erasure"] = 376210,
				["TwinGuardian"] = 370888,
				["Rescue"] = 370665,
				["GoldenHour"] = 378196,
				["Tailwind"] = 375556,
				["EssenceAttunement"] = 375722,
				["AttunedtotheDream"] = 376930,
				["EmeraldCommunion"] = 370960,
				["CauterizingFlame"] = 374251,
				["Ouroboros"] = 381921,
				["ExhilaratingBurst"] = 377100,
				["TimelessMagic"] = 376240,
				["ObsidianBulwark"] = 375406,
				["BlessingoftheBronze"] = 364342,
				["Lifebind"] = 373270,
				["AncientFlame"] = 369990,
				["LivingFlame"] = 361469,
				["WallopingBlow"] = 387341,
				["TimeLord"] = 372527,
				["Dreamwalker"] = 377082,
				["DraconicLegacy"] = 376166,
				["SpiritualClarity"] = 376150,
				["PermeatingChill"] = 370897,
				["PowerNexus"] = 369908,
				["Recall"] = 371806,
				["DeepBreath"] = 357210,
				["FireBreath"] = 382266,
				["Disintegrate"] = 356995,
				["EnergyLoop"] = 372233,
				["DreamBreath"] = 382614,
				["PotentMana"] = 418101,
				["EssenceBurst"] = 369297,
				["SourceofMagic"] = 369459,
				["SleepWalk"] = 360806,
				["FuryoftheAspects"] = 390386,
				["NaturalConvergence"] = 369913,
				["Landslide"] = 358385,
				["Unravel"] = 368432,
				["TemperedScales"] = 396571,
				["InherentResistance"] = 375544,
				["MassReturn"] = 361178,
				["FireWithin"] = 375577,
				["Empath"] = 376138,
				["RenewingBlaze"] = 374348,
				["ObsidianScales"] = 363916,
				["Overawe"] = 374346,
				["FieldofDreams"] = 370062,
				["TemporalCompression"] = 362874,
				["CallofYsera"] = 373834,
				["LifeforceMender"] = 376179,
				["Echo"] = 364343,
				["RenewingBreath"] = 371257,
				["Exuberance"] = 375542,
				["EnergizingFlame"] = 400006,
				["Panacea"] = 387761,
				["RushofVitality"] = 377086,
				["ResonatingSphere"] = 376236,
				["TimeDilation"] = 357170,
				["TerroroftheSkies"] = 371032,
				["VerdantEmbrace"] = 360995,
				["FociofLife"] = 375574,
				["TimeSpiral"] = 374968,
				["Zephyr"] = 374227,
				["ScarletAdaptation"] = 372469,
				["Mastery:Life-Binder"] = 363510,
				["InstinctiveArcana"] = 376164,
				["Naturalize"] = 360823,
				["InnateMagic"] = 375520,
				["Reversion"] = 366155,
				["Rewind"] = 363534,
				["GracePeriod"] = 376239,
				["Enkindled"] = 375554,
				["DreamFlight"] = 359816,
				["LushGrowth"] = 375561,
				["BountifulBloom"] = 370886,
				["SparkofInsight"] = 377099,
				["ExtendedFlight"] = 375517,
				["Punctuality"] = 371270,
				["AerialMastery"] = 365933,
				["JustinTime"] = 376204,
				["OppressingRoar"] = 372048,
				["FlowState"] = 385696,
				["RegenerativeMagic"] = 387787,
				["ForgerofMountains"] = 375528,
				["EmeraldBlossom"] = 355913,
				["TiptheScales"] = 370553,
				["FontofMagic"] = 375783,
				["BlastFurnace"] = 375510,
				["Expunge"] = 365585,
				["ProtractedTalons"] = 369909,
				["NozdormusTeachings"] = 376237,
				["ClobberingSweep"] = 375443,
				["Hover"] = 358267,
				["Return"] = 361227,
				["Spiritbloom"] = 382731,
				["Quell"] = 351338,
				["TemporalArtificer"] = 381922,
				["CycleofLife"] = 371832,
				["TimeofNeed"] = 368412,
				["Life-GiversFlame"] = 371426,
				["LeapingFlames"] = 369939,
				["HeavyWingbeats"] = 368838,
				["FlutteringSeedlings"] = 359793,
				["AzureStrike"] = 362969,
				["TemporalAnomaly"] = 373861,
				["DelayHarm"] = 376207,
			},
		},
		["Druid"] = {
			["Feral"] = {
				["NurturingInstinct"] = 33873,
				["Incarnation:AvatarofAshamane"] = 102543,
				["TravelForm"] = 783,
				["AdaptiveSwarm"] = 391888,
				["Mangle"] = 33917,
				["SouloftheForest"] = 158476,
				["IncessantTempest"] = 400140,
				["Typhoon"] = 132469,
				["ImprovedBarkskin"] = 327993,
				["UrsineVigor"] = 377842,
				["Berserk:HeartoftheLion"] = 391174,
				["Sabertooth"] = 202031,
				["Dreamwalk"] = 193753,
				["Hibernate"] = 2637,
				["NaturesVigil"] = 124974,
				["RipandTear"] = 391347,
				["Starfire"] = 197628,
				["ImprovedSunfire"] = 231050,
				["MassEntanglement"] = 102359,
				["AstralInfluence"] = 197524,
				["Predator"] = 202021,
				["CircleofLifeandDeath"] = 400320,
				["FerociousBite"] = 22568,
				["Revive"] = 50769,
				["UrsolsVortex"] = 102793,
				["Flap"] = 164862,
				["Thrash"] = 106832,
				["PouncingStrikes"] = 390772,
				["ImprovedSwipe"] = 400158,
				["Cyclone"] = 33786,
				["SkullBash"] = 106839,
				["Soothe"] = 2908,
				["Maim"] = 22570,
				["Regrowth"] = 8936,
				["MercilessClaws"] = 231063,
				["Barkskin"] = 22812,
				["FlightForm"] = 276029,
				["RisingLight,FallingNight"] = 417712,
				["WildCharge"] = 102401,
				["RagingFury"] = 391078,
				["Mastery:RazorClaws"] = 77493,
				["TigersTenacity"] = 391872,
				["BrutalSlash"] = 202028,
				["CharmWoodlandCreature"] = 127757,
				["GaleWinds"] = 400142,
				["FelineAdept"] = 300349,
				["SuddenAmbush"] = 384667,
				["AquaticForm"] = 276012,
				["Rake"] = 1822,
				["Rip"] = 1079,
				["ConvoketheSpirits"] = 391528,
				["DireFixation"] = 417710,
				["Berserk"] = 106951,
				["Starsurge"] = 197626,
				["MountForm"] = 210053,
				["VerdantHeart"] = 301768,
				["Wrath"] = 5176,
				["OmenofClarity"] = 16864,
				["Sunfire"] = 93402,
				["Rejuvenation"] = 774,
				["KillerInstinct"] = 108299,
				["TirelessEnergy"] = 383352,
				["IncapacitatingRoar"] = 99,
				["CarnivorousInstinct"] = 390902,
				["ProtectorofthePack"] = 378986,
				["FrenziedRegeneration"] = 22842,
				["PrimalWrath"] = 285381,
				["FranticMomentum"] = 391875,
				["LionsStrength"] = 391972,
				["MattedFur"] = 385786,
				["ImprovedStampedingRoar"] = 288826,
				["RampantFerocity"] = 391709,
				["Double-ClawedRake"] = 391700,
				["Renewal"] = 108238,
				["FeralInstinct"] = 16949,
				["RelentlessPredator"] = 393771,
				["UnbridledSwarm"] = 391951,
				["TigerDash"] = 252216,
				["AshamanesGuidance"] = 391548,
				["NaturalRecovery"] = 377796,
				["Shred"] = 5221,
				["DreadfulBleeding"] = 391045,
				["Ironfur"] = 192081,
				["ApexPredatorsCraving"] = 391881,
				["Rebirth"] = 20484,
				["ThickHide"] = 16931,
				["Veinripper"] = 391978,
				["TigersFury"] = 5217,
				["MoonkinForm"] = 197625,
				["MightyBash"] = 5211,
				["PrimalFury"] = 159286,
				["TearOpenWounds"] = 391785,
				["SurvivalInstincts"] = 61336,
				["InfectedWounds"] = 48484,
				["PredatorySwiftness"] = 16974,
				["Prowl"] = 5215,
				["Well-HonedInstincts"] = 377847,
				["Berserk:Frenzy"] = 384668,
				["TasteforBlood"] = 384665,
				["MomentofClarity"] = 236068,
				["BearForm"] = 5487,
				["TirelessPursuit"] = 377801,
				["Growl"] = 6795,
				["EntanglingRoots"] = 339,
				["StampedingRoar"] = 106898,
				["LycarasTeachings"] = 378988,
				["FelineSwiftness"] = 131768,
				["SaberJaws"] = 421432,
				["Forestwalk"] = 400129,
				["LunarInspiration"] = 155580,
				["Bloodtalons"] = 319439,
				["WildSlashes"] = 390864,
				["TreantForm"] = 114282,
				["MarkoftheWild"] = 1126,
				["RemoveCorruption"] = 2782,
				["ImprovedRejuvenation"] = 231040,
				["Moonfire"] = 8921,
				["FeralFrenzy"] = 274837,
				["ThrashingClaws"] = 405300,
				["CatForm"] = 768,
				["HeartoftheWild"] = 319454,
				["WildGrowth"] = 48438,
				["Dash"] = 1850,
				["Innervate"] = 29166,
				["ProtectiveGrowth"] = 391947,
				["Swiftmend"] = 18562,
			},
			["Balance"] = {
				["AstralSmolder"] = 394058,
				["NurturingInstinct"] = 33873,
				["MightyBash"] = 5211,
				["NaturesGrace"] = 393958,
				["SouloftheForest"] = 114107,
				["ImprovedBarkskin"] = 327993,
				["UrsineVigor"] = 377842,
				["Mangle"] = 33917,
				["SolarBeam"] = 78675,
				["WildGrowth"] = 48438,
				["Hibernate"] = 2637,
				["Mastery:AstralInvocation"] = 393014,
				["Starfire"] = 194153,
				["ImprovedSunfire"] = 231050,
				["MassEntanglement"] = 102359,
				["PrimalFury"] = 159286,
				["StellarFlare"] = 202347,
				["HeartoftheWild"] = 319454,
				["ImprovedStampedingRoar"] = 288826,
				["Regrowth"] = 8936,
				["UrsolsVortex"] = 102793,
				["IncessantTempest"] = 400140,
				["Thrash"] = 106832,
				["Typhoon"] = 132469,
				["FelineSwiftness"] = 131768,
				["Cyclone"] = 33786,
				["SkullBash"] = 106839,
				["RadiantMoonlight"] = 394121,
				["VerdantHeart"] = 301768,
				["NaturesVigil"] = 124974,
				["AstralInfluence"] = 197524,
				["OrbitBreaker"] = 383197,
				["FlightForm"] = 276029,
				["RisingLight,FallingNight"] = 417712,
				["WildCharge"] = 102401,
				["Incarnation:ChosenofElune"] = 102560,
				["WildSurges"] = 406890,
				["Solstice"] = 343647,
				["SunderedFirmament"] = 394094,
				["CharmWoodlandCreature"] = 127757,
				["Revive"] = 50769,
				["RemoveCorruption"] = 2782,
				["BalanceofAllThings"] = 394048,
				["AquaticForm"] = 276012,
				["OwlkinFrenzy"] = 231042,
				["TwinMoons"] = 279620,
				["Starfall"] = 191034,
				["KillerInstinct"] = 108299,
				["Flap"] = 164862,
				["Starsurge"] = 78674,
				["MountForm"] = 210053,
				["ConvoketheSpirits"] = 391528,
				["Wrath"] = 190984,
				["ImprovedRejuvenation"] = 231040,
				["Sunfire"] = 93402,
				["Rejuvenation"] = 774,
				["Dreamwalk"] = 193753,
				["Forestwalk"] = 400129,
				["Starlord"] = 202345,
				["GaleWinds"] = 400142,
				["ProtectorofthePack"] = 378986,
				["FrenziedRegeneration"] = 22842,
				["LightoftheSun"] = 202918,
				["CatForm"] = 768,
				["Barkskin"] = 22812,
				["MattedFur"] = 385786,
				["Swiftmend"] = 18562,
				["IncapacitatingRoar"] = 99,
				["ImprovedSwipe"] = 400158,
				["Maim"] = 22570,
				["StampedingRoar"] = 106898,
				["WildMushroom"] = 88747,
				["PowerofGoldrinn"] = 394046,
				["DenizenoftheDream"] = 394065,
				["ForceofNature"] = 205636,
				["NaturalRecovery"] = 377796,
				["Shred"] = 5221,
				["EntanglingRoots"] = 339,
				["CelestialAlignment"] = 194223,
				["TigerDash"] = 252216,
				["FriendoftheFae"] = 394081,
				["NaturesBalance"] = 202430,
				["WarriorofElune"] = 202425,
				["AetherialKindling"] = 327541,
				["MoonkinForm"] = 24858,
				["ThickHide"] = 16931,
				["StellarInnervation"] = 394115,
				["PrimordialArcanicPulsar"] = 393960,
				["OrbitalStrike"] = 390378,
				["TirelessPursuit"] = 377801,
				["UmbralEmbrace"] = 393760,
				["Prowl"] = 5215,
				["Well-HonedInstincts"] = 377847,
				["NewMoon"] = 274281,
				["UmbralIntensity"] = 383195,
				["Eclipse"] = 79577,
				["BearForm"] = 5487,
				["Ironfur"] = 192081,
				["Growl"] = 6795,
				["Rebirth"] = 20484,
				["WaningTwilight"] = 393956,
				["LunarShrapnel"] = 415169,
				["CosmicRapidity"] = 400059,
				["RattletheStars"] = 393954,
				["Renewal"] = 108238,
				["Swipe"] = 213764,
				["FuryofElune"] = 202770,
				["ElunesGuidance"] = 393991,
				["TreantForm"] = 114282,
				["AstralCommunion"] = 400636,
				["FerociousBite"] = 22568,
				["Soothe"] = 2908,
				["Moonfire"] = 8921,
				["ShootingStars"] = 202342,
				["LycarasTeachings"] = 378988,
				["MarkoftheWild"] = 1126,
				["Rip"] = 1079,
				["Rake"] = 1822,
				["Dash"] = 1850,
				["Innervate"] = 29166,
				["TravelForm"] = 783,
				["Starweaver"] = 393940,
			},
			["Guardian"] = {
				["Swiftmend"] = 18562,
				["ElunesFavored"] = 370586,
				["ImprovedSurvivalInstincts"] = 328767,
				["LayeredMane"] = 384721,
				["ReinforcedFur"] = 393618,
				["TwinMoonfire"] = 372567,
				["ImprovedBarkskin"] = 327993,
				["UrsocsGuidance"] = 393414,
				["Mangle"] = 33917,
				["Gore"] = 210706,
				["Mastery:NaturesGuardian"] = 155783,
				["Hibernate"] = 2637,
				["RendandTear"] = 204053,
				["Cyclone"] = 33786,
				["Starfire"] = 197628,
				["MoonlessNight"] = 400278,
				["MassEntanglement"] = 102359,
				["Brambles"] = 203953,
				["Typhoon"] = 132469,
				["CircleofLifeandDeath"] = 391969,
				["VulnerableFlesh"] = 372618,
				["CatForm"] = 768,
				["UrsolsVortex"] = 102793,
				["UntamedSavagery"] = 372943,
				["Thrash"] = 77758,
				["Reinvigoration"] = 372945,
				["ImprovedSwipe"] = 400158,
				["UrsocsFury"] = 377210,
				["SkullBash"] = 106839,
				["UrsineAdept"] = 300346,
				["Soothe"] = 2908,
				["NaturesVigil"] = 124974,
				["AstralInfluence"] = 197524,
				["FuryofNature"] = 370695,
				["FlightForm"] = 276029,
				["RisingLight,FallingNight"] = 417712,
				["WildCharge"] = 16979,
				["NurturingInstinct"] = 33873,
				["BloodFrenzy"] = 203962,
				["Revive"] = 50769,
				["MarkoftheWild"] = 1126,
				["CharmWoodlandCreature"] = 127757,
				["ToothandClaw"] = 135288,
				["RemoveCorruption"] = 2782,
				["InnateResolve"] = 377811,
				["AquaticForm"] = 276012,
				["Rake"] = 1822,
				["Rip"] = 1079,
				["Pulverize"] = 80313,
				["Maim"] = 22570,
				["Berserk"] = 50334,
				["Starsurge"] = 197626,
				["MountForm"] = 210053,
				["ConvoketheSpirits"] = 391528,
				["Raze"] = 400254,
				["VerdantHeart"] = 301768,
				["Sunfire"] = 93402,
				["Rejuvenation"] = 774,
				["Barkskin"] = 22812,
				["Forestwalk"] = 400129,
				["IncapacitatingRoar"] = 99,
				["ImprovedStampedingRoar"] = 288826,
				["FlashingClaws"] = 393427,
				["FrenziedRegeneration"] = 22842,
				["LightningReflexes"] = 231065,
				["HeartoftheWild"] = 319454,
				["Renewal"] = 108238,
				["MattedFur"] = 385786,
				["ThornsofIron"] = 400222,
				["LycarasTeachings"] = 378988,
				["GalacticGuardian"] = 203964,
				["ThickHide"] = 16931,
				["StampedingRoar"] = 77761,
				["UrsineVigor"] = 377842,
				["TravelForm"] = 783,
				["Earthwarden"] = 203974,
				["FelineSwiftness"] = 131768,
				["NaturalRecovery"] = 377796,
				["Shred"] = 5221,
				["EntanglingRoots"] = 339,
				["TigerDash"] = 252216,
				["GuardianofElune"] = 155578,
				["Rebirth"] = 20484,
				["SurvivalInstincts"] = 61336,
				["PrimalFury"] = 159286,
				["MoonkinForm"] = 197625,
				["BristlingFur"] = 155835,
				["SurvivaloftheFittest"] = 203965,
				["GoryFur"] = 200854,
				["AftertheWildfire"] = 371905,
				["Ironfur"] = 192081,
				["InfectedWounds"] = 345208,
				["TirelessPursuit"] = 377801,
				["Prowl"] = 5215,
				["Well-HonedInstincts"] = 377847,
				["DreamofCenarius"] = 372119,
				["GaleWinds"] = 400142,
				["IncessantTempest"] = 400140,
				["BearForm"] = 5487,
				["ViciousCycle"] = 371999,
				["Growl"] = 6795,
				["LunarBeam"] = 204066,
				["ImprovedSunfire"] = 231050,
				["ProtectorofthePack"] = 378986,
				["Maul"] = 6807,
				["RageoftheSleeper"] = 200851,
				["SouloftheForest"] = 158477,
				["Swipe"] = 213771,
				["Wrath"] = 5176,
				["KillerInstinct"] = 108299,
				["TreantForm"] = 114282,
				["Dreamwalk"] = 193753,
				["Incarnation:GuardianofUrsoc"] = 102558,
				["ImprovedRejuvenation"] = 231040,
				["Flap"] = 164862,
				["Regrowth"] = 8936,
				["FerociousBite"] = 22568,
				["UrsocsEndurance"] = 393611,
				["Moonfire"] = 8921,
				["MightyBash"] = 5211,
				["Dash"] = 1850,
				["Innervate"] = 29166,
				["WildGrowth"] = 48438,
				["ScintillatingMoonlight"] = 238049,
			},
			["Restoration"] = {
				["Swiftmend"] = 18562,
				["MightyBash"] = 5211,
				["WildSynthesis"] = 400533,
				["SouloftheForest"] = 158478,
				["CenariusGuidance"] = 393371,
				["ImprovedBarkskin"] = 327993,
				["UrsineVigor"] = 377842,
				["AdaptiveSwarm"] = 391888,
				["Incarnation:TreeofLife"] = 33891,
				["Hibernate"] = 2637,
				["HeartoftheWild"] = 319454,
				["Thrash"] = 106832,
				["ImprovedSwipe"] = 400158,
				["Cyclone"] = 33786,
				["SkullBash"] = 106839,
				["PassingSeasons"] = 382550,
				["NaturesVigil"] = 124974,
				["AstralInfluence"] = 197524,
				["FlightForm"] = 276029,
				["WildCharge"] = 102401,
				["CharmWoodlandCreature"] = 127757,
				["AquaticForm"] = 276012,
				["HarmoniousBlooming"] = 392256,
				["Maim"] = 22570,
				["Starsurge"] = 197626,
				["MountForm"] = 210053,
				["ConvoketheSpirits"] = 391528,
				["Sunfire"] = 93402,
				["Regenesis"] = 383191,
				["IncapacitatingRoar"] = 99,
				["Photosynthesis"] = 274902,
				["RegenerativeHeartwood"] = 392116,
				["MattedFur"] = 385786,
				["StampedingRoar"] = 106898,
				["Efflorescence"] = 145205,
				["UnbridledSwarm"] = 391951,
				["TranquilMind"] = 403521,
				["TigerDash"] = 252216,
				["Abundance"] = 207383,
				["Nourish"] = 50464,
				["ThickHide"] = 16931,
				["UnstoppableGrowth"] = 382559,
				["Swipe"] = 213764,
				["Verdancy"] = 392325,
				["Liveliness"] = 426702,
				["Cultivation"] = 200390,
				["Moonfire"] = 8921,
				["FerociousBite"] = 22568,
				["NaturesSplendor"] = 392288,
				["Ironbark"] = 102342,
				["VerdantInfusion"] = 392410,
				["TravelForm"] = 783,
				["Mangle"] = 33917,
				["WildGrowth"] = 48438,
				["Stonebark"] = 197061,
				["ImprovedNaturesCure"] = 392378,
				["RampantGrowth"] = 404521,
				["Starfire"] = 197628,
				["ImprovedSunfire"] = 231050,
				["MassEntanglement"] = 102359,
				["ImprovedRegrowth"] = 231032,
				["FlashofClarity"] = 392220,
				["UrsolsVortex"] = 102793,
				["GroveTending"] = 383192,
				["PrimalFury"] = 159286,
				["CenarionWard"] = 102351,
				["Regrowth"] = 8936,
				["NurturingDormancy"] = 392099,
				["Overgrowth"] = 203651,
				["Invigorate"] = 392160,
				["YserasGift"] = 145108,
				["GaleWinds"] = 400142,
				["Rake"] = 1822,
				["Rip"] = 1079,
				["EmbraceoftheDream"] = 392124,
				["KillerInstinct"] = 108299,
				["Barkskin"] = 22812,
				["ImprovedStampedingRoar"] = 288826,
				["Wrath"] = 5176,
				["Rejuvenation"] = 774,
				["ProtectorofthePack"] = 378986,
				["FrenziedRegeneration"] = 22842,
				["Undergrowth"] = 392301,
				["Revitalize"] = 212040,
				["VerdantHeart"] = 301768,
				["NurturingInstinct"] = 33873,
				["Innervate"] = 29166,
				["NaturalRecovery"] = 377796,
				["Shred"] = 5221,
				["EntanglingRoots"] = 339,
				["LycarasTeachings"] = 378988,
				["ImprovedIronbark"] = 382552,
				["Rebirth"] = 20484,
				["MarkoftheWild"] = 1126,
				["IncessantTempest"] = 400140,
				["Typhoon"] = 132469,
				["MoonkinForm"] = 197625,
				["Forestwalk"] = 400129,
				["Prowl"] = 5215,
				["MasterShapeshifter"] = 289237,
				["WakingDream"] = 392221,
				["ImprovedRejuvenation"] = 231040,
				["TirelessPursuit"] = 377801,
				["Flourish"] = 197721,
				["Well-HonedInstincts"] = 377847,
				["Tranquility"] = 740,
				["PoweroftheArchdruid"] = 392302,
				["Reforestation"] = 392356,
				["BearForm"] = 5487,
				["Growl"] = 6795,
				["NaturesSwiftness"] = 132158,
				["Dreamwalk"] = 193753,
				["GroveGuardians"] = 102693,
				["Dreamstate"] = 392162,
				["ImprovedWildGrowth"] = 328025,
				["BuddingLeaves"] = 392167,
				["CatForm"] = 768,
				["OmenofClarity"] = 113043,
				["FelineSwiftness"] = 131768,
				["LuxuriantSoil"] = 392315,
				["TreantForm"] = 114282,
				["Lifebloom"] = 188550,
				["Germination"] = 155675,
				["Soothe"] = 2908,
				["Flap"] = 164862,
				["InnerPeace"] = 197073,
				["Renewal"] = 108238,
				["Ironfur"] = 192081,
				["SpringBlossoms"] = 207385,
				["Revive"] = 50769,
				["Dash"] = 1850,
				["RisingLight,FallingNight"] = 417712,
				["NaturesCure"] = 88423,
				["Mastery:Harmony"] = 77495,
			},
		},
		["Priest"] = {
			["Discipline"] = {
				["Renew"] = 139,
				["PrayerofMending"] = 33076,
				["DarkIndulgence"] = 372972,
				["VoidTendrils"] = 108920,
				["PainandSuffering"] = 390689,
				["EnduringLuminescence"] = 390685,
				["InescapableTorment"] = 373427,
				["WordsofthePious"] = 377438,
				["AbyssalReverie"] = 373054,
				["Mindgames"] = 375901,
				["Manipulation"] = 390996,
				["LuminousBarrier"] = 271466,
				["ThroesofPain"] = 377422,
				["ShadowCovenant"] = 314867,
				["PsychicVoice"] = 196704,
				["ProtectoroftheFrail"] = 373035,
				["Exaltation"] = 373042,
				["Shadowfiend"] = 34433,
				["Resurrection"] = 2006,
				["Schism"] = 424509,
				["VoidShield"] = 280749,
				["AegisofWrath"] = 238135,
				["AngelicBulwark"] = 108945,
				["SanguineTeachings"] = 373218,
				["SheerTerror"] = 390919,
				["EssenceDevourer"] = 415479,
				["VoidSummoner"] = 390770,
				["DispelMagic"] = 528,
				["TwistofFate"] = 390972,
				["Mindbender"] = 123040,
				["BindingHeals"] = 368275,
				["ShadowWord:Death"] = 32379,
				["BlazeofLight"] = 215768,
				["ImprovedFade"] = 390670,
				["MassDispel"] = 32375,
				["VampiricEmbrace"] = 15286,
				["ImprovedFlashHeal"] = 393870,
				["Expiation"] = 390832,
				["MassResurrection"] = 212036,
				["MindSoothe"] = 453,
				["TranslucentImage"] = 373446,
				["PainSuppression"] = 33206,
				["MindVision"] = 2096,
				["BorrowedTime"] = 390691,
				["DeathandMadness"] = 321291,
				["FocusedMending"] = 372354,
				["SinsoftheMany"] = 280391,
				["Castigation"] = 193134,
				["PoweroftheDarkSide"] = 198068,
				["VoidShift"] = 108968,
				["ImprovedPurify"] = 390632,
				["BlessedRecovery"] = 390767,
				["MindBlast"] = 8092,
				["DesperatePrayer"] = 19236,
				["HeavensWrath"] = 421558,
				["ShatteredPerceptions"] = 391112,
				["Atonement"] = 81749,
				["MindControl"] = 605,
				["Evangelism"] = 246287,
				["MentalAgility"] = 341167,
				["TrainofThought"] = 390693,
				["Rapture"] = 47536,
				["TwinsoftheSunPriestess"] = 373466,
				["PowerWord:Shield"] = 17,
				["BrightPupil"] = 390684,
				["Fade"] = 586,
				["Sanlayn"] = 199855,
				["Apathy"] = 390668,
				["WealandWoe"] = 390786,
				["DivineStar"] = 110744,
				["Mastery:Grace"] = 271534,
				["PowerInfusion"] = 10060,
				["BodyandSoul"] = 64129,
				["FocusedWill"] = 45243,
				["HarshDiscipline"] = 373180,
				["AngelicFeather"] = 121536,
				["Purify"] = 527,
				["FlashHeal"] = 2061,
				["Halo"] = 120517,
				["Benevolence"] = 415416,
				["Rhapsody"] = 390622,
				["UnwaveringWill"] = 373456,
				["ShieldDiscipline"] = 197045,
				["AngelsMercy"] = 238100,
				["HolyNova"] = 132157,
				["Smite"] = 585,
				["PetrifyingScream"] = 55676,
				["Contrition"] = 197419,
				["LightsInspiration"] = 373450,
				["PainTransformation"] = 372991,
				["LeapofFaith"] = 73325,
				["Inspiration"] = 390676,
				["PainfulPunishment"] = 390686,
				["PowerWord:Life"] = 373481,
				["PowerWord:Radiance"] = 194509,
				["Sanctuary"] = 231682,
				["Indemnity"] = 373049,
				["OverloadedwithLight"] = 421557,
				["DominateMind"] = 205364,
				["Levitate"] = 1706,
				["ShackleUndead"] = 9484,
				["PurgetheWicked"] = 204197,
				["ProtectiveLight"] = 193063,
				["CrystallineReflection"] = 373457,
				["PowerWord:Barrier"] = 62618,
				["TwilightEquilibrium"] = 390705,
				["MaliciousIntent"] = 372969,
				["Lenience"] = 238063,
				["PsychicScream"] = 8122,
				["UltimatePenitence"] = 421453,
				["FromDarknessComesLight"] = 390615,
				["PowerWord:Fortitude"] = 21562,
				["TwilightCorruption"] = 373065,
				["MovewithGrace"] = 390620,
				["Phantasm"] = 108942,
				["RevelinPurity"] = 373003,
				["Penance"] = 47540,
				["SurgeofLight"] = 109186,
				["DivineAegis"] = 47515,
				["LightsPromise"] = 322115,
				["TitheEvasion"] = 373223,
				["SpellWarding"] = 390667,
			},
			["Shadow"] = {
				["Renew"] = 139,
				["VoidTorrent"] = 263165,
				["DistortedReality"] = 409044,
				["MentalDecay"] = 375994,
				["DarkEvangelism"] = 391095,
				["MindControl"] = 605,
				["WordsofthePious"] = 377438,
				["IdolofYogg-Saron"] = 373273,
				["Hallucinations"] = 280752,
				["InescapableTorment"] = 373427,
				["ThroesofPain"] = 377422,
				["SurgeofInsanity"] = 391399,
				["DarkAscension"] = 391109,
				["MindsEye"] = 407470,
				["ProtectiveLight"] = 193063,
				["AuspiciousSpirits"] = 155271,
				["ShadowWord:Pain"] = 589,
				["PsychicVoice"] = 196704,
				["Shadowfiend"] = 34433,
				["PsychicLink"] = 199484,
				["Manipulation"] = 390996,
				["DesperatePrayer"] = 19236,
				["MentalFortitude"] = 377065,
				["EssenceDevourer"] = 415479,
				["Benevolence"] = 415416,
				["PhantasmalPathogen"] = 407469,
				["ScreamsoftheVoid"] = 375767,
				["Mindbender"] = 200174,
				["Mastermind"] = 391151,
				["AngelicBulwark"] = 108945,
				["Phantasm"] = 108942,
				["ImprovedFade"] = 390670,
				["MassDispel"] = 32375,
				["VampiricEmbrace"] = 15286,
				["Shadowform"] = 232698,
				["Deathspeaker"] = 392507,
				["IdolofCThun"] = 377349,
				["MindSoothe"] = 453,
				["MindVision"] = 2096,
				["UnfurlingDarkness"] = 341273,
				["SanguineTeachings"] = 373218,
				["ShadowWord:Death"] = 32379,
				["VoidShield"] = 280749,
				["SheerTerror"] = 390919,
				["PowerWord:Fortitude"] = 21562,
				["MindDevourer"] = 373202,
				["ShackleUndead"] = 9484,
				["VoidShift"] = 108968,
				["FromDarknessComesLight"] = 390615,
				["BlessedRecovery"] = 390767,
				["TormentedSpirits"] = 391284,
				["FocusedMending"] = 372354,
				["Malediction"] = 373221,
				["ShatteredPerceptions"] = 391112,
				["Mindgames"] = 375901,
				["PurifyDisease"] = 213634,
				["PsychicScream"] = 8122,
				["MentalAgility"] = 341167,
				["Resurrection"] = 2006,
				["ShadowyInsight"] = 375888,
				["TwinsoftheSunPriestess"] = 373466,
				["ShadowyApparitions"] = 341491,
				["DivineStar"] = 122121,
				["Fade"] = 586,
				["Sanlayn"] = 199855,
				["InsidiousIre"] = 373212,
				["DevouringPlague"] = 335467,
				["ShadowCrash"] = 205385,
				["Silence"] = 15487,
				["PowerInfusion"] = 10060,
				["Apathy"] = 390668,
				["FocusedWill"] = 45243,
				["TranslucentImage"] = 373446,
				["UnwaveringWill"] = 373456,
				["Levitate"] = 1706,
				["FlashHeal"] = 2061,
				["Halo"] = 120644,
				["DominateMind"] = 205364,
				["VoidTendrils"] = 108920,
				["AngelicFeather"] = 121536,
				["Inspiration"] = 390676,
				["AngelsMercy"] = 238100,
				["BindingHeals"] = 368275,
				["Rhapsody"] = 390622,
				["Mastery:ShadowWeaving"] = 343690,
				["LeapofFaith"] = 73325,
				["LightsInspiration"] = 373450,
				["HolyNova"] = 132157,
				["WhisperingShadows"] = 406777,
				["MindFlay"] = 15407,
				["PetrifyingScream"] = 55676,
				["PowerWord:Life"] = 373481,
				["IdolofNZoth"] = 373280,
				["LastWord"] = 263716,
				["MindMelt"] = 391090,
				["IdolofYShaarj"] = 373310,
				["Intangibility"] = 288733,
				["VoidEruption"] = 228260,
				["ThoughtHarvester"] = 406788,
				["DeathandMadness"] = 321291,
				["VampiricTouch"] = 34914,
				["CrystallineReflection"] = 373457,
				["PowerWord:Shield"] = 17,
				["Dispersion"] = 47585,
				["DispelMagic"] = 528,
				["MindBlast"] = 8092,
				["Misery"] = 238558,
				["PrayerofMending"] = 33076,
				["TwistofFate"] = 390972,
				["MindSpike"] = 73510,
				["PsychicHorror"] = 64044,
				["MovewithGrace"] = 390620,
				["AncientMadness"] = 341240,
				["ImprovedFlashHeal"] = 393870,
				["MaddeningTouch"] = 391228,
				["SurgeofLight"] = 109186,
				["BodyandSoul"] = 64129,
				["Voidtouched"] = 407430,
				["TitheEvasion"] = 373223,
				["SpellWarding"] = 390667,
			},
			["Holy"] = {
				["Renew"] = 139,
				["PrayerofMending"] = 33076,
				["Pontifex"] = 390980,
				["GuardianAngel"] = 200209,
				["Heal"] = 2060,
				["DesperateTimes"] = 391381,
				["HarmoniousApparatus"] = 390994,
				["DesperatePrayer"] = 19236,
				["VoidTendrils"] = 108920,
				["Manipulation"] = 390996,
				["MindControl"] = 605,
				["Shadowfiend"] = 34433,
				["Benediction"] = 193157,
				["WordsofthePious"] = 377438,
				["SurgeofLight"] = 109186,
				["HolyMending"] = 391154,
				["EssenceDevourer"] = 415479,
				["PrayerfulLitany"] = 391209,
				["ThroesofPain"] = 377422,
				["HolyWord:Sanctify"] = 34861,
				["EmpoweredRenew"] = 391339,
				["BindingHeals"] = 368275,
				["RenewedFaith"] = 341997,
				["DivineImage"] = 392988,
				["ShadowWord:Pain"] = 589,
				["ShadowWord:Death"] = 32379,
				["SanctifiedPrayers"] = 196489,
				["Lightwell"] = 372835,
				["AngelicBulwark"] = 108945,
				["DivineHymn"] = 64843,
				["SpiritofRedemption"] = 20711,
				["AngelicFeather"] = 121536,
				["Benevolence"] = 415416,
				["Resurrection"] = 2006,
				["TwistofFate"] = 390972,
				["PrismaticEchoes"] = 390967,
				["Rhapsody"] = 390622,
				["SymbolofHope"] = 64901,
				["SheerTerror"] = 390919,
				["ImprovedFade"] = 390670,
				["PrayerCircle"] = 321377,
				["Censure"] = 200199,
				["TranslucentImage"] = 373446,
				["ImprovedPurify"] = 390632,
				["MassResurrection"] = 212036,
				["MindSoothe"] = 453,
				["DivineWord"] = 372760,
				["ImprovedFlashHeal"] = 393870,
				["SanguineTeachings"] = 373218,
				["HealingChorus"] = 390881,
				["VoidShield"] = 280749,
				["FocusedMending"] = 372354,
				["PowerWord:Fortitude"] = 21562,
				["Enlightenment"] = 193155,
				["Afterlife"] = 196707,
				["VoidShift"] = 108968,
				["FromDarknessComesLight"] = 390615,
				["BlessedRecovery"] = 390767,
				["RapidRecovery"] = 391368,
				["EmpyrealBlaze"] = 372616,
				["GalesofSong"] = 372370,
				["TrailofLight"] = 200128,
				["Apathy"] = 390668,
				["ResonantWords"] = 372309,
				["GuardianSpirit"] = 47788,
				["MentalAgility"] = 341167,
				["ProtectiveLight"] = 193063,
				["BodyandSoul"] = 64129,
				["TwinsoftheSunPriestess"] = 373466,
				["Sanlayn"] = 199855,
				["HolyWord:Chastise"] = 88625,
				["Fade"] = 586,
				["HolyWord:Salvation"] = 265202,
				["HolyWord:Serenity"] = 2050,
				["FlashHeal"] = 2061,
				["Purify"] = 527,
				["DivineStar"] = 110744,
				["LightoftheNaaru"] = 196985,
				["AnsweredPrayers"] = 391387,
				["FocusedWill"] = 45243,
				["MassDispel"] = 32375,
				["RevitalizingPrayers"] = 391208,
				["PrayersoftheVirtuous"] = 390977,
				["SayYourPrayers"] = 391186,
				["Halo"] = 120517,
				["UnwaveringWill"] = 373456,
				["Mastery:EchoofLight"] = 77485,
				["PowerInfusion"] = 10060,
				["Inspiration"] = 390676,
				["AngelsMercy"] = 238100,
				["PrayerofHealing"] = 596,
				["Smite"] = 585,
				["PetrifyingScream"] = 55676,
				["HolyNova"] = 132157,
				["LightsInspiration"] = 373450,
				["BurningVehemence"] = 372307,
				["ShatteredPerceptions"] = 391112,
				["CosmicRipple"] = 238136,
				["LeapofFaith"] = 73325,
				["PowerWord:Life"] = 373481,
				["Epiphany"] = 414553,
				["ShackleUndead"] = 9484,
				["DominateMind"] = 205364,
				["MiracleWorker"] = 235587,
				["GuardiansoftheLight"] = 196437,
				["EverlastingLight"] = 391161,
				["Levitate"] = 1706,
				["VampiricEmbrace"] = 15286,
				["CrisisManagement"] = 390954,
				["CrystallineReflection"] = 373457,
				["PowerWord:Shield"] = 17,
				["DeathandMadness"] = 321291,
				["Lightweaver"] = 390992,
				["Apotheosis"] = 200183,
				["PsychicScream"] = 8122,
				["DivineService"] = 391233,
				["MindVision"] = 2096,
				["Mindgames"] = 375901,
				["CircleofHealing"] = 204883,
				["MovewithGrace"] = 390620,
				["Phantasm"] = 108942,
				["HolyFire"] = 14914,
				["DispelMagic"] = 528,
				["Restitution"] = 391124,
				["Orison"] = 390947,
				["PsychicVoice"] = 196704,
				["TitheEvasion"] = 373223,
				["SpellWarding"] = 390667,
			},
		},
		["Hunter"] = {
			["Marksmanship"] = {
				["PrimalRage"] = 272678,
				["PoisonInjection"] = 378014,
				["NaturesEndurance"] = 388042,
				["Mastery:SniperTraining"] = 193468,
				["BindingShackles"] = 321468,
				["WildernessMedicine"] = 343242,
				["WailingArrow"] = 392060,
				["IntheRhythm"] = 407404,
				["WindrunnersBarrage"] = 389866,
				["AimedShot"] = 19434,
				["Multi-Shot"] = 257620,
				["LegacyoftheWindrunners"] = 406425,
				["ImprovedKillShot"] = 343248,
				["ScareBeast"] = 1513,
				["MasterMarksman"] = 260309,
				["Volley"] = 260243,
				["SentinelsProtection"] = 388057,
				["TargetPractice"] = 321287,
				["ConcussiveShot"] = 5116,
				["TrickShots"] = 257621,
				["ArcaneShot"] = 185358,
				["CrackShot"] = 321293,
				["Barrage"] = 120360,
				["Streamline"] = 260367,
				["Readiness"] = 389865,
				["Stampede"] = 201430,
				["TacticalReload"] = 400472,
				["HuntersAvoidance"] = 384799,
				["TranquilizingShot"] = 19801,
				["Salvo"] = 400456,
				["Pathfinding"] = 378002,
				["WindrunnersGuidance"] = 378905,
				["SentinelsPerception"] = 388056,
				["ImprovedTraps"] = 343247,
				["Camouflage"] = 199483,
				["KillerInstinct"] = 273887,
				["Intimidation"] = 19577,
				["RazorFragments"] = 384790,
				["CallingtheShots"] = 260404,
				["Exhilaration"] = 109304,
				["WingClip"] = 195645,
				["SteadyShot"] = 56641,
				["SurgingShots"] = 391559,
				["HuntersMark"] = 257284,
				["ChimaeraShot"] = 342049,
				["RoarofSacrifice"] = 53480,
				["Sharpshooter"] = 378907,
				["HuntersKnowledge"] = 378766,
				["FocusedAim"] = 378767,
				["PreciseShots"] = 260240,
				["Fetch"] = 125050,
				["UnerringVision"] = 386878,
				["Entrapment"] = 393344,
				["ImprovedSteadyShot"] = 321018,
				["AspectoftheCheetah"] = 186257,
				["LoneSurvivor"] = 388039,
				["SerpentstalkersTrickery"] = 378888,
				["KillShot"] = 53351,
				["EagleEye"] = 6197,
				["SerpentSting"] = 271788,
				["KeenEyesight"] = 378004,
				["KillerAccuracy"] = 378765,
				["SteadyFocus"] = 193533,
				["AspectoftheTurtle"] = 186265,
				["Bulletstorm"] = 389019,
				["Bullseye"] = 204089,
				["ImprovedTranquilizingShot"] = 343244,
				["LightAmmo"] = 378913,
				["TarTrap"] = 187698,
				["CarefulAim"] = 260228,
				["ScatterShot"] = 213691,
				["KillCommand"] = 34026,
				["SurvivaloftheFittest"] = 264735,
				["BindingShot"] = 109248,
				["DeathChakram"] = 375891,
				["LoneWolf"] = 155228,
				["LockandLoad"] = 194595,
				["ImprovedKillCommand"] = 378010,
				["Trailblazer"] = 199921,
				["NaturalMending"] = 270581,
				["Bombardment"] = 405804,
				["Deadeye"] = 321460,
				["Misdirection"] = 34477,
				["Posthaste"] = 109215,
				["EagletalonsTrueFocus"] = 389449,
				["SentinelOwl"] = 388045,
				["CounterShot"] = 147362,
				["Flare"] = 1543,
				["SerratedShots"] = 389882,
				["RejuvenatingWind"] = 385539,
				["BurstingShot"] = 186387,
				["QuickLoad"] = 378771,
				["FeignDeath"] = 5384,
				["Disengage"] = 781,
				["BeastMaster"] = 378007,
				["Trueshot"] = 288613,
				["HighExplosiveTrap"] = 236776,
				["BornToBeWild"] = 266921,
				["SteelTrap"] = 162488,
				["EyesoftheBeast"] = 321297,
				["AlphaPredator"] = 269737,
				["HydrasBite"] = 260241,
				["Deathblow"] = 378769,
				["ArcticBola"] = 390231,
				["RapidFire"] = 257044,
				["FreezingTrap"] = 187650,
				["ExplosiveShot"] = 212431,
				["HeavyAmmo"] = 378910,
				["PlayDead"] = 209997,
			},
			["Beast Mastery"] = {
				["PrimalRage"] = 272678,
				["PoisonInjection"] = 378014,
				["NaturesEndurance"] = 388042,
				["BrutalCompanion"] = 386870,
				["BeastCleave"] = 115939,
				["DirePack"] = 378745,
				["WildernessMedicine"] = 343242,
				["WailingArrow"] = 392060,
				["Multi-Shot"] = 2643,
				["Fetch"] = 125050,
				["ImprovedKillShot"] = 343248,
				["ScareBeast"] = 1513,
				["MasterMarksman"] = 260309,
				["KindredSpirits"] = 56315,
				["SteelTrap"] = 162488,
				["SentinelsProtection"] = 388057,
				["DireFrenzy"] = 385810,
				["ConcussiveShot"] = 5116,
				["ScatterShot"] = 213691,
				["ThrilloftheHunt"] = 257944,
				["Posthaste"] = 109215,
				["Barrage"] = 120360,
				["MasterHandler"] = 424558,
				["SharpBarbs"] = 378205,
				["Stampede"] = 201430,
				["Misdirection"] = 34477,
				["TranquilizingShot"] = 19801,
				["AMurderofCrows"] = 131894,
				["Pathfinding"] = 378002,
				["WildInstincts"] = 378442,
				["SentinelsPerception"] = 388056,
				["ImprovedTraps"] = 343247,
				["Camouflage"] = 199483,
				["KillerInstinct"] = 273887,
				["Intimidation"] = 19577,
				["Exhilaration"] = 109304,
				["KillCleave"] = 378207,
				["WingClip"] = 195645,
				["PlayDead"] = 209997,
				["CobraSenses"] = 378244,
				["RoarofSacrifice"] = 53480,
				["FreezingTrap"] = 187650,
				["KillCommand"] = 34026,
				["Savagery"] = 424557,
				["Flare"] = 1543,
				["KillerCobra"] = 199532,
				["Mastery:MasterofBeasts"] = 76657,
				["Entrapment"] = 393344,
				["AspectoftheBeast"] = 191384,
				["AspectoftheCheetah"] = 186257,
				["LoneSurvivor"] = 388039,
				["EagleEye"] = 6197,
				["KillShot"] = 53351,
				["ArcaneShot"] = 185358,
				["SerpentSting"] = 271788,
				["KeenEyesight"] = 378004,
				["Trailblazer"] = 199921,
				["Stomp"] = 199530,
				["Bloodshed"] = 321530,
				["CobraShot"] = 193455,
				["NaturalMending"] = 270581,
				["ImprovedTranquilizingShot"] = 343244,
				["BornToBeWild"] = 266921,
				["ExoticBeasts"] = 53270,
				["CalloftheWild"] = 359844,
				["WildCall"] = 185789,
				["ScentofBlood"] = 193532,
				["SurvivaloftheFittest"] = 264735,
				["BindingShot"] = 109248,
				["DeathChakram"] = 375891,
				["HuntersMark"] = 257284,
				["Disengage"] = 781,
				["ImprovedKillCommand"] = 378010,
				["FeignDeath"] = 5384,
				["PiercingFangs"] = 392053,
				["OnewiththePack"] = 199528,
				["SerratedShots"] = 389882,
				["CobraSting"] = 378750,
				["WarOrders"] = 393933,
				["BarbedWrath"] = 231548,
				["SentinelOwl"] = 388045,
				["CounterShot"] = 147362,
				["PackTactics"] = 321014,
				["BarbedShot"] = 217200,
				["RejuvenatingWind"] = 385539,
				["TarTrap"] = 187698,
				["DireCommand"] = 378743,
				["BestialWrath"] = 19574,
				["DireBeast"] = 120679,
				["AnimalCompanion"] = 267116,
				["KillerCommand"] = 378740,
				["HighExplosiveTrap"] = 236776,
				["BloodyFrenzy"] = 407412,
				["BindingShackles"] = 321468,
				["EyesoftheBeast"] = 321297,
				["AspectoftheTurtle"] = 186265,
				["HydrasBite"] = 260241,
				["HuntersPrey"] = 378210,
				["ArcticBola"] = 390231,
				["AlphaPredator"] = 269737,
				["HuntersAvoidance"] = 384799,
				["ExplosiveShot"] = 212431,
				["BeastMaster"] = 378007,
				["TrainingExpert"] = 378209,
			},
			["Survival"] = {
				["PoisonInjection"] = 378014,
				["NaturesEndurance"] = 388042,
				["BindingShackles"] = 321468,
				["WildernessMedicine"] = 343242,
				["ImprovedWildfireBomb"] = 321290,
				["Fetch"] = 125050,
				["ImprovedKillShot"] = 343248,
				["ScareBeast"] = 1513,
				["MasterMarksman"] = 260309,
				["SteelTrap"] = 162488,
				["SentinelsProtection"] = 388057,
				["SweepingSpear"] = 378950,
				["ConcussiveShot"] = 5116,
				["ScatterShot"] = 213691,
				["ArcaneShot"] = 185358,
				["Posthaste"] = 109215,
				["RuthlessMarauder"] = 385718,
				["Bloodseeker"] = 260248,
				["WildfireInfusion"] = 271014,
				["TacticalAdvantage"] = 378951,
				["CoordinatedAssault"] = 360952,
				["Stampede"] = 201430,
				["BirdsofPrey"] = 260331,
				["KillerCompanion"] = 378955,
				["TranquilizingShot"] = 19801,
				["Pathfinding"] = 378002,
				["SentinelsPerception"] = 388056,
				["MongooseBite"] = 259387,
				["Camouflage"] = 199483,
				["PlayDead"] = 209997,
				["KillerInstinct"] = 273887,
				["SteadyShot"] = 56641,
				["Intimidation"] = 19577,
				["WingClip"] = 195645,
				["HuntersMark"] = 257284,
				["Exhilaration"] = 109304,
				["Mastery:SpiritBond"] = 263135,
				["VipersVenom"] = 268501,
				["Flare"] = 1543,
				["SpearFocus"] = 378953,
				["FlankingStrike"] = 269751,
				["RoarofSacrifice"] = 53480,
				["AspectoftheTurtle"] = 186265,
				["KillCommand"] = 259489,
				["FreezingTrap"] = 187650,
				["QuickShot"] = 378940,
				["LoneSurvivor"] = 388039,
				["BornToBeWild"] = 266921,
				["Entrapment"] = 393344,
				["Muzzle"] = 187707,
				["AspectoftheCheetah"] = 186257,
				["EagleEye"] = 6197,
				["TermsofEngagement"] = 265895,
				["Butchery"] = 212436,
				["Spearhead"] = 360966,
				["SerpentSting"] = 271788,
				["KeenEyesight"] = 378004,
				["Trailblazer"] = 199921,
				["ShrapnelBomb"] = 270335,
				["HighExplosiveTrap"] = 236776,
				["SharpEdges"] = 378948,
				["NaturalMending"] = 270581,
				["ImprovedTranquilizingShot"] = 343244,
				["Bombardier"] = 389880,
				["TarTrap"] = 187698,
				["Carve"] = 187708,
				["FrenzyStrikes"] = 294029,
				["AspectoftheEagle"] = 186289,
				["SurvivaloftheFittest"] = 264735,
				["BindingShot"] = 109248,
				["DeathChakram"] = 375891,
				["Disengage"] = 781,
				["IntenseFocus"] = 385709,
				["ImprovedKillCommand"] = 378010,
				["Lunge"] = 378934,
				["ImprovedTraps"] = 343247,
				["Barrage"] = 120360,
				["Ferocity"] = 378916,
				["FuryoftheEagle"] = 203415,
				["Ranger"] = 385695,
				["Misdirection"] = 34477,
				["ExplosivesExpert"] = 378937,
				["KillShot"] = 320976,
				["SentinelOwl"] = 388045,
				["SerratedShots"] = 389882,
				["RejuvenatingWind"] = 385539,
				["Harpoon"] = 190925,
				["TipoftheSpear"] = 260285,
				["FeignDeath"] = 5384,
				["BloodyClaws"] = 385737,
				["GuerrillaTactics"] = 264332,
				["EnergeticAlly"] = 378961,
				["RaptorStrike"] = 186270,
				["WildfireBomb"] = 259495,
				["DeadlyDuo"] = 378962,
				["EyesoftheBeast"] = 321297,
				["CommandPet"] = 272651,
				["HydrasBite"] = 260241,
				["HuntersAvoidance"] = 384799,
				["ArcticBola"] = 390231,
				["AlphaPredator"] = 269737,
				["FlankersAdvantage"] = 263186,
				["ExplosiveShot"] = 212431,
				["BeastMaster"] = 378007,
				["CoordinatedKill"] = 385739,
			},
		},
		["Death Knight"] = {
			["Unholy"] = {
				["MightofThassarian"] = 374111,
				["UnholyCommand"] = 316941,
				["ImprovedFesteringStrike"] = 316867,
				["UnholyAssault"] = 207289,
				["Assimilation"] = 374383,
				["Mastery:Dreadblade"] = 77515,
				["DeathsReach"] = 276079,
				["ScourgeStrike"] = 55090,
				["Anti-MagicShell"] = 48707,
				["UnholyBond"] = 374261,
				["MindFreeze"] = 47528,
				["RuneMastery"] = 374574,
				["RupturedViscera"] = 390236,
				["WilloftheNecropolis"] = 206967,
				["SoulReaper"] = 343294,
				["ChainsofIce"] = 45524,
				["SacrificialPact"] = 327574,
				["Anti-MagicZone"] = 51052,
				["ImprovedDeathCoil"] = 377580,
				["MarchofDarkness"] = 391546,
				["DarkCommand"] = 56222,
				["Epidemic"] = 207317,
				["Coldthirst"] = 378848,
				["ClawingShadows"] = 207311,
				["UnholyEndurance"] = 389682,
				["CommanderoftheDead"] = 390259,
				["InfectedClaws"] = 207272,
				["ControlUndead"] = 111673,
				["ProliferatingChill"] = 373930,
				["WraithWalk"] = 212552,
				["RunicCorruption"] = 51462,
				["Plaguebringer"] = 390175,
				["IceboundFortitude"] = 48792,
				["AbominationLimb"] = 383269,
				["FeastingStrikes"] = 390161,
				["GloomWard"] = 391571,
				["IcyTalons"] = 194878,
				["Outbreak"] = 77575,
				["DarkTransformation"] = 63560,
				["MercilessStrikes"] = 373923,
				["EternalAgony"] = 390268,
				["UnholyGround"] = 374265,
				["SuddenDoom"] = 49530,
				["ReplenishingWounds"] = 377585,
				["EmpowerRuneWeapon"] = 47568,
				["DeathsEcho"] = 356367,
				["InsidiousChill"] = 391566,
				["UnholyAura"] = 377440,
				["BlindingSleet"] = 207167,
				["VileContagion"] = 390279,
				["Permafrost"] = 207200,
				["EbonFever"] = 207269,
				["DeathCoil"] = 47541,
				["CleavingStrikes"] = 316916,
				["ArmyoftheDamned"] = 276837,
				["ArmyoftheDead"] = 42650,
				["GripoftheDead"] = 273952,
				["Festermight"] = 377590,
				["FesteringStrike"] = 85948,
				["DeathGrip"] = 49576,
				["RunicMastery"] = 390166,
				["DeathStrike"] = 49998,
				["ImprovedDeathStrike"] = 374277,
				["RottenTouch"] = 390275,
				["DeathPact"] = 48743,
				["Superstrain"] = 390283,
				["Enfeeble"] = 392566,
				["OnaPaleHorse"] = 51986,
				["SummonGargoyle"] = 49206,
				["AllWillServe"] = 194916,
				["ClenchingGrasp"] = 389679,
				["GhoulishFrenzy"] = 377587,
				["BloodDraw"] = 374598,
				["PathofFrost"] = 3714,
				["UnholyPact"] = 319230,
				["VeteranoftheThirdWar"] = 48263,
				["RaiseDead"] = 46584,
				["Defile"] = 152280,
				["Pestilence"] = 277234,
				["Acclimation"] = 373926,
				["RunicAttenuation"] = 207104,
				["Suppression"] = 374049,
				["RaiseAlly"] = 61999,
				["Runeforging"] = 53428,
				["UnholyBlight"] = 115989,
				["Anti-MagicBarrier"] = 205727,
				["DarkSuccor"] = 178819,
				["Lichborne"] = 49039,
				["DeathandDecay"] = 43265,
				["Reaping"] = 377514,
				["DeathGate"] = 50977,
				["BloodScent"] = 374030,
				["DeathRot"] = 377537,
				["CoilofDevastation"] = 390270,
				["MagusoftheDead"] = 390196,
				["HarbingerofDoom"] = 276023,
				["Morbidity"] = 377592,
				["Brittle"] = 374504,
				["Asphyxiate"] = 221562,
				["DeathsAdvance"] = 48265,
				["BurstingSores"] = 207264,
				["Apocalypse"] = 275699,
			},
			["Frost"] = {
				["MightofThassarian"] = 374111,
				["ImprovedFrostStrike"] = 316803,
				["Assimilation"] = 374383,
				["InvigoratingFreeze"] = 377092,
				["DeathsReach"] = 276079,
				["Anti-MagicShell"] = 48707,
				["RunicCommand"] = 376251,
				["FrostwhelpsAid"] = 377226,
				["UnholyBond"] = 374261,
				["ShatteringBlade"] = 207057,
				["MindFreeze"] = 47528,
				["RuneMastery"] = 374574,
				["DeathsAdvance"] = 48265,
				["WilloftheNecropolis"] = 206967,
				["SoulReaper"] = 343294,
				["ChainsofIce"] = 45524,
				["SacrificialPact"] = 327574,
				["Anti-MagicZone"] = 51052,
				["MarchofDarkness"] = 391546,
				["ImprovedRime"] = 316838,
				["FrigidExecutioner"] = 377073,
				["Coldthirst"] = 378848,
				["MightoftheFrozenWastes"] = 81333,
				["UnholyEndurance"] = 389682,
				["Everfrost"] = 376938,
				["UnleashedFrenzy"] = 376905,
				["ImprovedObliterate"] = 317198,
				["ControlUndead"] = 111673,
				["PiercingChill"] = 377351,
				["AbsoluteZero"] = 377047,
				["ProliferatingChill"] = 373930,
				["WraithWalk"] = 212552,
				["PillarofFrost"] = 51271,
				["MurderousEfficiency"] = 207061,
				["IceboundFortitude"] = 48792,
				["RunicEmpowerment"] = 81229,
				["HornofWinter"] = 57330,
				["DarkCommand"] = 56222,
				["MercilessStrikes"] = 373923,
				["EmpowerRuneWeapon"] = 47568,
				["FrostStrike"] = 49143,
				["AbominationLimb"] = 383269,
				["GloomWard"] = 391571,
				["DeathandDecay"] = 43265,
				["InexorableAssault"] = 253593,
				["InsidiousChill"] = 391566,
				["EnduringChill"] = 377376,
				["BlindingSleet"] = 207167,
				["IcyTalons"] = 194878,
				["Rime"] = 59057,
				["BitingCold"] = 377056,
				["DeathCoil"] = 47541,
				["FrostwyrmsFury"] = 279302,
				["GatheringStorm"] = 194912,
				["Avalanche"] = 207142,
				["GripoftheDead"] = 273952,
				["Frostscythe"] = 207230,
				["Permafrost"] = 207200,
				["DeathGrip"] = 49576,
				["Obliterate"] = 49020,
				["DeathStrike"] = 49998,
				["PathofFrost"] = 3714,
				["HowlingBlast"] = 49184,
				["DeathPact"] = 48743,
				["ColdHeart"] = 281208,
				["ImprovedDeathStrike"] = 374277,
				["OnaPaleHorse"] = 51986,
				["VeteranoftheThirdWar"] = 48263,
				["Enfeeble"] = 392566,
				["BreathofSindragosa"] = 152279,
				["Mastery:FrozenHeart"] = 77514,
				["ClenchingGrasp"] = 389679,
				["Cold-BloodedRage"] = 377083,
				["Runeforging"] = 53428,
				["Icebreaker"] = 392950,
				["RaiseDead"] = 46585,
				["DeathsEcho"] = 356367,
				["BloodDraw"] = 374598,
				["ChillStreak"] = 305392,
				["EnduringStrength"] = 377190,
				["Suppression"] = 374049,
				["RaiseAlly"] = 61999,
				["RunicAttenuation"] = 207104,
				["Icecap"] = 207126,
				["Anti-MagicBarrier"] = 205727,
				["GlacialAdvance"] = 194913,
				["Lichborne"] = 49039,
				["Obliteration"] = 281238,
				["DarkSuccor"] = 178819,
				["DeathGate"] = 50977,
				["BloodScent"] = 374030,
				["RemorselessWinter"] = 196770,
				["UnholyGround"] = 374265,
				["KillingMachine"] = 51128,
				["RageoftheFrozenChampion"] = 377076,
				["Bonegrinder"] = 377098,
				["Brittle"] = 374504,
				["Asphyxiate"] = 221562,
				["CleavingStrikes"] = 316916,
				["Acclimation"] = 373926,
				["FatalFixation"] = 405166,
			},
			["Blood"] = {
				["MightofThassarian"] = 374111,
				["DeathsCaress"] = 195292,
				["Ossuary"] = 219786,
				["Assimilation"] = 374383,
				["BloodBoil"] = 50842,
				["BloodTap"] = 221699,
				["DeathsReach"] = 276079,
				["Anti-MagicShell"] = 48707,
				["UnholyBond"] = 374261,
				["MindFreeze"] = 47528,
				["RuneMastery"] = 374574,
				["DeathsAdvance"] = 48265,
				["WilloftheNecropolis"] = 206967,
				["UmbilicusEternus"] = 391517,
				["ChainsofIce"] = 45524,
				["SacrificialPact"] = 327574,
				["Anti-MagicZone"] = 51052,
				["MarchofDarkness"] = 391546,
				["DarkCommand"] = 56222,
				["Coldthirst"] = 378848,
				["Marrowrend"] = 195182,
				["UnholyEndurance"] = 389682,
				["Bonestorm"] = 194844,
				["BloodFeast"] = 391386,
				["ControlUndead"] = 111673,
				["ProliferatingChill"] = 373930,
				["WraithWalk"] = 212552,
				["BloodFortification"] = 374721,
				["Acclimation"] = 373926,
				["Tombstone"] = 219809,
				["CrimsonScourge"] = 81136,
				["IceboundFortitude"] = 48792,
				["Blooddrinker"] = 206931,
				["AbominationLimb"] = 383269,
				["IcyTalons"] = 194878,
				["GloomWard"] = 391571,
				["ImprovedHeartStrike"] = 374717,
				["EmpowerRuneWeapon"] = 47568,
				["MercilessStrikes"] = 373923,
				["DancingRuneWeapon"] = 49028,
				["CleavingStrikes"] = 316916,
				["SoulReaper"] = 343294,
				["RedThirst"] = 205723,
				["DeathandDecay"] = 43265,
				["GripoftheDead"] = 273952,
				["InsidiousChill"] = 391566,
				["FoulBulwark"] = 206974,
				["BlindingSleet"] = 207167,
				["HeartStrike"] = 206930,
				["Permafrost"] = 207200,
				["DeathsEcho"] = 356367,
				["LeechingStrike"] = 377629,
				["RaiseDead"] = 46585,
				["ImprovedDeathStrike"] = 374277,
				["Heartrend"] = 377655,
				["ImprovedVampiricBlood"] = 317133,
				["PerseveranceoftheEbonBlade"] = 374747,
				["Anti-MagicBarrier"] = 205727,
				["InsatiableBlade"] = 377637,
				["ReinforcedBones"] = 374737,
				["Hemostasis"] = 273946,
				["EverlastingBond"] = 377668,
				["Voracious"] = 273953,
				["DeathPact"] = 48743,
				["Bloodworms"] = 195679,
				["Purgatory"] = 114556,
				["OnaPaleHorse"] = 51986,
				["Consumption"] = 274156,
				["Enfeeble"] = 392566,
				["VeteranoftheThirdWar"] = 48263,
				["Heartbreaker"] = 221536,
				["Coagulopathy"] = 391477,
				["PathofFrost"] = 3714,
				["RapidDecomposition"] = 194662,
				["SanguineGround"] = 391458,
				["Runeforging"] = 53428,
				["BloodDraw"] = 374598,
				["RuneTap"] = 194679,
				["RunicAttenuation"] = 207104,
				["Mastery:BloodShield"] = 77513,
				["Suppression"] = 374049,
				["RaiseAlly"] = 61999,
				["UnholyGround"] = 374265,
				["ClenchingGrasp"] = 389679,
				["IronHeart"] = 391395,
				["TighteningGrasp"] = 206970,
				["Lichborne"] = 49039,
				["DeathStrike"] = 49998,
				["DeathGrip"] = 49576,
				["DeathGate"] = 50977,
				["BloodScent"] = 374030,
				["GorefiendsGrasp"] = 108199,
				["DeathCoil"] = 47541,
				["Bloodshot"] = 391398,
				["RelishinBlood"] = 317610,
				["VampiricBlood"] = 55233,
				["Brittle"] = 374504,
				["Asphyxiate"] = 221562,
				["ImprovedBoneShield"] = 374715,
				["MarkofBlood"] = 206940,
				["ShatteringBone"] = 377640,
			},
		},
		["Warlock"] = {
			["Demonology"] = {
				["Soulburn"] = 385899,
				["SargereiTechnique"] = 405955,
				["Shadowflame"] = 384069,
				["UnendingBreath"] = 5697,
				["GrimoireofSynergy"] = 171975,
				["Demoniac"] = 426115,
				["SoulLeech"] = 108370,
				["ImpGangBoss"] = 387445,
				["Horrify"] = 56244,
				["CarnivorousStalkers"] = 386194,
				["HeavyHanded"] = 416183,
				["RitualofDoom"] = 342601,
				["WrathfulMinion"] = 386864,
				["ReignofTyranny"] = 427684,
				["FelandSteel"] = 386200,
				["SubjugateDemon"] = 1098,
				["ProfaneBargain"] = 389576,
				["AccruedVitality"] = 386613,
				["FelArmor"] = 386124,
				["AntoranArmaments"] = 387494,
				["DemonicResilience"] = 389590,
				["MortalCoil"] = 6789,
				["GrandWarlocksDesign"] = 387084,
				["DemonicEmbrace"] = 288843,
				["AmplifyCurse"] = 328774,
				["CursesofEnfeeblement"] = 386105,
				["ImmutableHatred"] = 405670,
				["Darkfury"] = 264874,
				["DemonSkin"] = 219272,
				["InnerDemons"] = 267216,
				["Shadowfury"] = 30283,
				["KazaaksFinalCurse"] = 387483,
				["Mastery:MasterDemonologist"] = 77219,
				["NerzhulsVolition"] = 387526,
				["DarkAccord"] = 386659,
				["HowlofTerror"] = 5484,
				["DreadCalling"] = 387391,
				["Demonbolt"] = 264178,
				["Fear"] = 5782,
				["FelDomination"] = 333889,
				["AbyssWalker"] = 389609,
				["SpitefulReconstitution"] = 428394,
				["DemonicCircle:Teleport"] = 48020,
				["FelSynergy"] = 389367,
				["DemonicInspiration"] = 386858,
				["ShadowsBite"] = 387322,
				["BurningRush"] = 111400,
				["CreateHealthstone"] = 6201,
				["Imp-erator"] = 416230,
				["PowerSiphon"] = 264130,
				["StrengthofWill"] = 317138,
				["ShadowBolt"] = 686,
				["DemonicCircle"] = 48018,
				["TheExpendables"] = 387600,
				["ShadowInvocation"] = 422054,
				["CallDreadstalkers"] = 104316,
				["DrainLife"] = 234153,
				["DemonicCore"] = 267102,
				["Implosion"] = 196277,
				["Guillotine"] = 386833,
				["SweetSouls"] = 386620,
				["FelPact"] = 386113,
				["EyeofKilrogg"] = 126,
				["InfernalCommand"] = 387549,
				["IchorofDevils"] = 386664,
				["StolenPower"] = 387602,
				["InquisitorsGaze"] = 386344,
				["CreateSoulwell"] = 29893,
				["SoulboundTyrant"] = 334585,
				["FiendishStride"] = 386110,
				["Lifeblood"] = 386646,
				["TeachingsoftheBlackHarvest"] = 385881,
				["CurseofExhaustion"] = 334275,
				["Cavitation"] = 416154,
				["SocretharsGuile"] = 405936,
				["Banish"] = 710,
				["FelSunder"] = 387399,
				["TeachingsoftheSatyr"] = 387972,
				["Corruption"] = 172,
				["TheHoundmastersStratagem"] = 267170,
				["DemonicFortitude"] = 386617,
				["Nightmare"] = 386648,
				["MaleficImpact"] = 416341,
				["CurseofTongues"] = 1714,
				["DarkPact"] = 108416,
				["Dreadlash"] = 264078,
				["Grimoire:Felguard"] = 111898,
				["HandofGuldan"] = 105174,
				["DemonicCalling"] = 205145,
				["SoulStrike"] = 428344,
				["SacrificedSouls"] = 267214,
				["SoulLink"] = 108415,
				["DemonicKnowledge"] = 386185,
				["ResoluteBarrier"] = 389359,
				["SoulShards"] = 246985,
				["GrimFeast"] = 386689,
				["NetherPortal"] = 267217,
				["AnnihilanTraining"] = 386174,
				["GuldansAmbition"] = 387578,
				["Doom"] = 603,
				["SummonDemonicTyrant"] = 265187,
				["FelInvocation"] = 428351,
				["DemonicGateway"] = 111771,
				["FrequentDonor"] = 386686,
				["CurseofWeakness"] = 702,
				["HealthFunnel"] = 755,
				["UmbralBlaze"] = 405798,
				["DemonicStrength"] = 267171,
				["RitualofSummoning"] = 698,
				["PactoftheImpMother"] = 387541,
				["SummonVilefiend"] = 264119,
				["SoulConduit"] = 215941,
				["Soulstone"] = 20707,
				["SummonSoulkeeper"] = 386256,
				["UnendingResolve"] = 104773,
				["CommandDemon"] = 119898,
				["BilescourgeBombers"] = 267211,
				["TheCodexofXerrath"] = 101508,
			},
			["Destruction"] = {
				["Soulburn"] = 385899,
				["SargereiTechnique"] = 405955,
				["Shadowflame"] = 384069,
				["UnendingBreath"] = 5697,
				["GrimoireofSynergy"] = 171975,
				["Decimation"] = 387176,
				["Backdraft"] = 196406,
				["SoulLeech"] = 108370,
				["Horrify"] = 56244,
				["DemonicCircle:Teleport"] = 48020,
				["Inferno"] = 270545,
				["GrimoireofSacrifice"] = 108503,
				["SummonInfernal"] = 1122,
				["ScaldingFlames"] = 388832,
				["WrathfulMinion"] = 386864,
				["SubjugateDemon"] = 1098,
				["Shadowburn"] = 17877,
				["AccruedVitality"] = 386613,
				["DemonicResilience"] = 389590,
				["MortalCoil"] = 6789,
				["GrandWarlocksDesign"] = 387084,
				["AmplifyCurse"] = 328774,
				["CursesofEnfeeblement"] = 386105,
				["ImprovedConflagrate"] = 231793,
				["ProfaneBargain"] = 389576,
				["DemonSkin"] = 219272,
				["Immolate"] = 348,
				["TheCodexofXerrath"] = 101508,
				["AshenRemains"] = 387252,
				["DemonicEmbrace"] = 288843,
				["SoulShards"] = 246985,
				["RollingHavoc"] = 387569,
				["HowlofTerror"] = 5484,
				["RainofChaos"] = 266086,
				["SoulConduit"] = 215941,
				["DiabolicEmbers"] = 387173,
				["FelDomination"] = 333889,
				["DarkAccord"] = 386659,
				["SoulLink"] = 108415,
				["PowerOverwhelming"] = 387279,
				["FelSynergy"] = 389367,
				["DemonicInspiration"] = 386858,
				["ChannelDemonfire"] = 196447,
				["AbyssWalker"] = 389609,
				["CurseofWeakness"] = 702,
				["Havoc"] = 80240,
				["RitualofDoom"] = 342601,
				["StrengthofWill"] = 317138,
				["FrequentDonor"] = 386686,
				["Chaosbringer"] = 422057,
				["DemonicCircle"] = 48018,
				["DemonicGateway"] = 111771,
				["ChaosBolt"] = 116858,
				["DrainLife"] = 234153,
				["InfernalBrand"] = 387475,
				["RoaringBlaze"] = 205184,
				["Mastery:ChaoticEnergies"] = 77220,
				["SweetSouls"] = 386620,
				["FelPact"] = 386113,
				["Shadowfury"] = 30283,
				["IchorofDevils"] = 386664,
				["Cataclysm"] = 152108,
				["ImprovedImmolate"] = 387093,
				["InquisitorsGaze"] = 386344,
				["CreateSoulwell"] = 29893,
				["Pandemonium"] = 387509,
				["FiendishStride"] = 386110,
				["RitualofRuin"] = 387156,
				["Pyrogenics"] = 387095,
				["CurseofExhaustion"] = 334275,
				["Fear"] = 5782,
				["SocretharsGuile"] = 405936,
				["Banish"] = 710,
				["TeachingsoftheBlackHarvest"] = 385881,
				["TeachingsoftheSatyr"] = 387972,
				["ReverseEntropy"] = 205148,
				["Nightmare"] = 386648,
				["DemonicFortitude"] = 386617,
				["MasterRitualist"] = 387165,
				["Flashpoint"] = 387259,
				["CurseofTongues"] = 1714,
				["CryHavoc"] = 387522,
				["BurningRush"] = 111400,
				["CrashingChaos"] = 417234,
				["CreateHealthstone"] = 6201,
				["InternalCombustion"] = 266134,
				["Eradication"] = 196412,
				["Ruin"] = 387103,
				["ChaosIncarnate"] = 387275,
				["Lifeblood"] = 386646,
				["Conflagrate"] = 17962,
				["DarkPact"] = 108416,
				["ConflagrationofChaos"] = 387108,
				["ExplosivePotential"] = 388827,
				["SoulFire"] = 6353,
				["ResoluteBarrier"] = 389359,
				["GrimFeast"] = 386689,
				["RagingDemonfire"] = 387166,
				["DimensionalRift"] = 387976,
				["BurntoAshes"] = 387153,
				["Mayhem"] = 387506,
				["RainofFire"] = 5740,
				["HealthFunnel"] = 755,
				["Incinerate"] = 29722,
				["AvatarofDestruction"] = 387159,
				["RitualofSummoning"] = 698,
				["EyeofKilrogg"] = 126,
				["Backlash"] = 387384,
				["FireandBrimstone"] = 196408,
				["Soulstone"] = 20707,
				["SummonSoulkeeper"] = 386256,
				["UnendingResolve"] = 104773,
				["CommandDemon"] = 119898,
				["FelArmor"] = 386124,
				["Darkfury"] = 264874,
			},
			["Affliction"] = {
				["Soulburn"] = 385899,
				["SargereiTechnique"] = 405955,
				["Shadowflame"] = 384069,
				["UnendingBreath"] = 5697,
				["GrimoireofSynergy"] = 171975,
				["PandemicInvocation"] = 386759,
				["KindledMalice"] = 405330,
				["SoulFlame"] = 199471,
				["Horrify"] = 56244,
				["DemonicCircle:Teleport"] = 48020,
				["RitualofDoom"] = 342601,
				["SacrolashsDarkStrike"] = 386986,
				["AbsoluteCorruption"] = 196103,
				["GrimoireofSacrifice"] = 108503,
				["WrathfulMinion"] = 386864,
				["DoomBlossom"] = 416621,
				["SubjugateDemon"] = 1098,
				["AccruedVitality"] = 386613,
				["DemonicResilience"] = 389590,
				["MortalCoil"] = 6789,
				["GrandWarlocksDesign"] = 387084,
				["PhantomSingularity"] = 205179,
				["AmplifyCurse"] = 328774,
				["CursesofEnfeeblement"] = 386105,
				["WitheringBolt"] = 386976,
				["DemonSkin"] = 219272,
				["DemonicEmbrace"] = 288843,
				["HowlofTerror"] = 5484,
				["SeizedVitality"] = 387250,
				["SoulConduit"] = 215941,
				["FelDomination"] = 333889,
				["Mastery:PotentAfflictions"] = 77215,
				["Agony"] = 980,
				["TheCodexofXerrath"] = 101508,
				["FelSynergy"] = 389367,
				["DemonicInspiration"] = 386858,
				["SoulShards"] = 246985,
				["DreadTouch"] = 389775,
				["SoulLeech"] = 108370,
				["Shadowfury"] = 30283,
				["Darkfury"] = 264874,
				["StrengthofWill"] = 317138,
				["FrequentDonor"] = 386686,
				["EyeofKilrogg"] = 126,
				["Nightfall"] = 108558,
				["SoulLink"] = 108415,
				["DrainSoul"] = 198590,
				["DrainLife"] = 234153,
				["UnstableAffliction"] = 316099,
				["DarkVirtuosity"] = 405327,
				["GrimFeast"] = 386689,
				["SweetSouls"] = 386620,
				["FelPact"] = 386113,
				["InevitableDemise"] = 334319,
				["DemonicCircle"] = 48018,
				["TormentedCrescendo"] = 387075,
				["CreepingDeath"] = 264000,
				["InquisitorsGaze"] = 386344,
				["CreateSoulwell"] = 29893,
				["Haunt"] = 48181,
				["FiendishStride"] = 386110,
				["ShadowEmbrace"] = 32388,
				["VileTaint"] = 278350,
				["CurseofExhaustion"] = 334275,
				["SocretharsGuile"] = 405936,
				["ResoluteBarrier"] = 389359,
				["XavianTeachings"] = 317031,
				["SoulRot"] = 386997,
				["TeachingsoftheSatyr"] = 387972,
				["IchorofDevils"] = 386664,
				["DarkPact"] = 108416,
				["DemonicFortitude"] = 386617,
				["AgonizingCorruption"] = 386922,
				["WrathofConsumption"] = 387065,
				["CurseofTongues"] = 1714,
				["GrimReach"] = 389992,
				["BurningRush"] = 111400,
				["FocusedMalignancy"] = 399668,
				["CreateHealthstone"] = 6201,
				["ProfaneBargain"] = 389576,
				["SeedofCorruption"] = 27243,
				["XaviusGambit"] = 416615,
				["MalevolentVisionary"] = 387273,
				["Lifeblood"] = 386646,
				["SiphonLife"] = 63106,
				["SowtheSeeds"] = 196226,
				["TeachingsoftheBlackHarvest"] = 385881,
				["MaleficRapture"] = 324536,
				["SoulSwap"] = 386951,
				["WritheinAgony"] = 196102,
				["Nightmare"] = 386648,
				["HauntedSoul"] = 387301,
				["DarkHarvest"] = 387016,
				["DemonicGateway"] = 111771,
				["Soul-EatersGluttony"] = 389630,
				["Banish"] = 710,
				["HealthFunnel"] = 755,
				["Corruption"] = 172,
				["AbyssWalker"] = 389609,
				["RitualofSummoning"] = 698,
				["CurseofWeakness"] = 702,
				["DarkAccord"] = 386659,
				["Fear"] = 5782,
				["Soulstone"] = 20707,
				["SummonSoulkeeper"] = 386256,
				["UnendingResolve"] = 104773,
				["CommandDemon"] = 119898,
				["FelArmor"] = 386124,
				["SummonDarkglare"] = 205180,
			},
		},
	}
	local className, classFilename, classId = UnitClass("player")
	local currentSpec = GetSpecialization()
	local id, name, description, icon, background, role = GetSpecializationInfo(currentSpec)
	MaxDps.SpellTable = MaxDpsSpellTable[idtoclass[classId]][idtospec[id]]
	--MaxDps.SpellInfoTable = {}
end

function MaxDps:UNIT_ENTERED_VEHICLE(_, unit)
	if unit == 'player' and self.rotationEnabled then
		self:DisableRotation();
	end
end

function MaxDps:UNIT_EXITED_VEHICLE(_, unit)
	if unit == 'player' then
		self:InitRotations();
		self:EnableRotation();
	end
end

function MaxDps:PLAYER_TARGET_CHANGED()
	if self.rotationEnabled then
		if UnitIsFriend('player', 'target') then
			return
		else
			self:InvokeNextSpell();
		end
	end
end

function MaxDps:PLAYER_REGEN_DISABLED()
	if self.db.global.onCombatEnter and not self.rotationEnabled then
		self:Print(self.Colors.Success .. 'Auto enable on combat!');
		self:InitRotations();
		self:EnableRotation();
	end
end

function MaxDps:ButtonFetch()
	if self.rotationEnabled then
		if self.fetchTimer then
			self:CancelTimer(self.fetchTimer);
		end
		self.fetchTimer = self:ScheduleTimer('Fetch', 0.5);
	end
end

function MaxDps:PrepareFrameData()
	if not self.FrameData then
		self.FrameData = {
			cooldown  = self.PlayerCooldowns,
			activeDot = self.ActiveDots
		};
	end

	self.FrameData.timeShift, self.FrameData.currentSpell, self.FrameData.gcdRemains = MaxDps:EndCast();
	self.FrameData.gcd = self:GlobalCooldown();
	self.FrameData.buff, self.FrameData.debuff = MaxDps:CollectAuras();
	self.FrameData.talents = self.PlayerTalents;
	self.FrameData.azerite = self.AzeriteTraits;
	self.FrameData.essences = self.AzeriteEssences;
	self.FrameData.covenant = self.CovenantInfo;
	self.FrameData.runeforge = self.LegendaryBonusIds;
	self.FrameData.spellHistory = self.spellHistory;
	self.FrameData.timeToDie = self:GetTimeToDie();
end

function MaxDps:InvokeNextSpell()
	-- invoke spell check
	local oldSkill = self.Spell;

	self:PrepareFrameData();

	self:GlowConsumables();

	-- Removed backward compatibility
	self.Spell = self:NextSpell();

	if (oldSkill ~= self.Spell or oldSkill == nil) and self.Spell ~= nil then
		self:GlowNextSpell(self.Spell);
		if WeakAuras then
			WeakAuras.ScanEvents('MAXDPS_SPELL_UPDATE', self.Spell);
		end
	end

	if self.Spell == nil and oldSkill ~= nil then
		self:GlowClear();
		if WeakAuras then
			WeakAuras.ScanEvents('MAXDPS_SPELL_UPDATE', nil);
		end
	end
end

function MaxDps:InitRotations()
	self:Print(self.Colors.Info .. 'Initializing rotations');
	self:CountTier()

	local _, _, classId = UnitClass('player');
	local spec = GetSpecialization();
	self.ClassId = classId;
	self.Spec = spec;

	if not self.Custom then
		self.Custom = self:GetModule('Custom');
	end

	self.Custom:LoadCustomRotations();
	local customRotation = self.Custom:GetCustomRotation(classId, spec);

	if customRotation then
		self.NextSpell = customRotation.fn;

		self:Print(self.Colors.Success .. 'Loaded Custom Rotation: ' .. customRotation.name);
	else
		self:LoadModule();
	end
end

function MaxDps:LoadModule()
	if self.Classes[self.ClassId] == nil then
		self:Print(self.Colors.Error .. 'Invalid player class, please contact author of addon.');
		return
	end

	local className = self.Classes[self.ClassId];
	local module = 'MaxDps_' .. className;
	local _, _, _, _, reason = GetAddOnInfo(module);

	if IsAddOnLoaded(module) then
		self:EnableRotationModule(className);
		return
	end

	if reason == 'MISSING' or reason == 'DISABLED' then
		self:Print(self.Colors.Error .. 'Could not find class module ' .. module .. ', reason: ' .. reason);
		self:Print(self.Colors.Error .. 'Make sure to install class module or create custom rotation');
		self:Print(self.Colors.Error .. 'Missing addon: ' .. module);
		return
	end

	LoadAddOn(module);

	self:InitTTD();
	self:EnableRotationModule(className);
end

function MaxDps:EnableRotationModule(className)
	local loaded = self:EnableModule(className);

	if not loaded then
		self:Print(self.Colors.Error .. 'Could not find load module ' .. className .. ', reason: OUTDATED');
	else
		self:Print(self.Colors.Info .. 'Finished Loading class module');
	end
end
